"""Contains all the data models used in inputs/outputs"""

from .action_result import ActionResult
from .action_type import ActionType
from .agent_step import AgentStep
from .agent_step_input_type_3 import AgentStepInputType3
from .agent_step_input_type_7_item import AgentStepInputType7Item
from .agent_step_input_type_8_item import AgentStepInputType8Item
from .agent_step_metadata import AgentStepMetadata
from .agent_step_output_type_3 import AgentStepOutputType3
from .agent_step_output_type_7_item import AgentStepOutputType7Item
from .agent_step_output_type_8_item import AgentStepOutputType8Item
from .agentic_workflow_success_scorer import AgenticWorkflowSuccessScorer
from .agentic_workflow_success_template import AgenticWorkflowSuccessTemplate
from .aggregate_metrics import AggregateMetrics
from .aggregator import Aggregator
from .alert import Alert
from .alert_condition import AlertCondition
from .alert_condition_type import AlertConditionType
from .alert_configuration_response import AlertConfigurationResponse
from .alert_importance import AlertImportance
from .alert_monitor_type import AlertMonitorType
from .alert_status_response import AlertStatusResponse
from .alerts_configuration import AlertsConfiguration
from .anthropic_integration import AnthropicIntegration
from .anthropic_integration_create import AnthropicIntegrationCreate
from .anthropic_integration_extra_type_0 import AnthropicIntegrationExtraType0
from .api_key_action import ApiKeyAction
from .api_key_delete_response import ApiKeyDeleteResponse
from .api_key_login_request import ApiKeyLoginRequest
from .auth_method import AuthMethod
from .auto_gen_result import AutoGenResult
from .available_integrations import AvailableIntegrations
from .aws_bedrock_integration import AwsBedrockIntegration
from .aws_bedrock_integration_extra_type_0 import AwsBedrockIntegrationExtraType0
from .aws_credential_type import AwsCredentialType
from .aws_sage_maker_integration import AwsSageMakerIntegration
from .aws_sage_maker_integration_create import AwsSageMakerIntegrationCreate
from .aws_sage_maker_integration_create_token import AwsSageMakerIntegrationCreateToken
from .aws_sage_maker_integration_extra_type_0 import AwsSageMakerIntegrationExtraType0
from .azure_authentication_type import AzureAuthenticationType
from .azure_integration import AzureIntegration
from .azure_integration_create import AzureIntegrationCreate
from .azure_integration_create_headers_type_0 import AzureIntegrationCreateHeadersType0
from .azure_integration_extra_type_0 import AzureIntegrationExtraType0
from .azure_integration_headers_type_0 import AzureIntegrationHeadersType0
from .azure_model_deployment import AzureModelDeployment
from .b_box import BBox
from .bar_chart import BarChart
from .base_aws_integration_create import BaseAwsIntegrationCreate
from .base_aws_integration_create_token import BaseAwsIntegrationCreateToken
from .base_galileo_step import BaseGalileoStep
from .base_galileo_step_input_type_3 import BaseGalileoStepInputType3
from .base_galileo_step_input_type_7_item import BaseGalileoStepInputType7Item
from .base_galileo_step_input_type_8_item import BaseGalileoStepInputType8Item
from .base_galileo_step_metadata import BaseGalileoStepMetadata
from .base_galileo_step_output_type_3 import BaseGalileoStepOutputType3
from .base_galileo_step_output_type_7_item import BaseGalileoStepOutputType7Item
from .base_galileo_step_output_type_8_item import BaseGalileoStepOutputType8Item
from .base_prompt_template_response import BasePromptTemplateResponse
from .base_prompt_template_version import BasePromptTemplateVersion
from .base_prompt_template_version_response import BasePromptTemplateVersionResponse
from .base_scorer import BaseScorer
from .base_scorer_aggregates_type_0 import BaseScorerAggregatesType0
from .base_scorer_extra_type_0 import BaseScorerExtraType0
from .base_scorer_version_response import BaseScorerVersionResponse
from .bleu_scorer import BleuScorer
from .body_create_or_update_registered_scorers_put import BodyCreateOrUpdateRegisteredScorersPut
from .body_login_email_login_post import BodyLoginEmailLoginPost
from .body_update_prompt_dataset_projects_project_id_prompt_datasets_dataset_id_put import (
    BodyUpdatePromptDatasetProjectsProjectIdPromptDatasetsDatasetIdPut,
)
from .body_upload_dataset_datasets_post import BodyUploadDatasetDatasetsPost
from .body_upload_file_projects_project_id_upload_file_post import BodyUploadFileProjectsProjectIdUploadFilePost
from .body_upload_prompt_evaluation_dataset_projects_project_id_prompt_datasets_post import (
    BodyUploadPromptEvaluationDatasetProjectsProjectIdPromptDatasetsPost,
)
from .bucketed_metrics import BucketedMetrics
from .bulk_feedback_rating_create import BulkFeedbackRatingCreate
from .bulk_feedback_rating_delete import BulkFeedbackRatingDelete
from .bulk_feedback_rating_status import BulkFeedbackRatingStatus
from .bulk_feedback_request import BulkFeedbackRequest
from .cartograph_cluster import CartographCluster
from .cartograph_cluster_response import CartographClusterResponse
from .categorical_prompt_filter_param import CategoricalPromptFilterParam
from .category_filter_operator import CategoryFilterOperator
from .cbo_cluster_request import CBOClusterRequest
from .cbo_cluster_response import CBOClusterResponse
from .cbo_run_cluster import CBORunCluster
from .chain_poll_template import ChainPollTemplate
from .chain_row import ChainRow
from .chain_row_inputs_type_0 import ChainRowInputsType0
from .chain_row_params import ChainRowParams
from .chain_step import ChainStep
from .chain_step_input_type_3 import ChainStepInputType3
from .chain_step_input_type_7_item import ChainStepInputType7Item
from .chain_step_input_type_8_item import ChainStepInputType8Item
from .chain_step_metadata import ChainStepMetadata
from .chain_step_output_type_3 import ChainStepOutputType3
from .chain_step_output_type_7_item import ChainStepOutputType7Item
from .chain_step_output_type_8_item import ChainStepOutputType8Item
from .changes import Changes
from .chunk_attribution_utilization_scorer import ChunkAttributionUtilizationScorer
from .chunk_attribution_utilization_scorer_type import ChunkAttributionUtilizationScorerType
from .chunk_attribution_utilization_template import ChunkAttributionUtilizationTemplate
from .circle import Circle
from .collaborator_role import CollaboratorRole
from .collaborator_role_info import CollaboratorRoleInfo
from .collaborator_update import CollaboratorUpdate
from .column_category import ColumnCategory
from .community_response import CommunityResponse
from .compare_runs_response import CompareRunsResponse
from .completeness_scorer import CompletenessScorer
from .completeness_scorer_type import CompletenessScorerType
from .completeness_template import CompletenessTemplate
from .composite_project_settings import CompositeProjectSettings
from .composite_project_settings_metric_weights_configuration_type_0 import (
    CompositeProjectSettingsMetricWeightsConfigurationType0,
)
from .content_request import ContentRequest
from .context_adherence_scorer import ContextAdherenceScorer
from .context_adherence_scorer_type import ContextAdherenceScorerType
from .context_relevance_scorer import ContextRelevanceScorer
from .correctness_scorer import CorrectnessScorer
from .create_alert_configuration_request import CreateAlertConfigurationRequest
from .create_api_key_request import CreateApiKeyRequest
from .create_api_key_response import CreateApiKeyResponse
from .create_compute_score_request import CreateComputeScoreRequest
from .create_generated_scorer_request import CreateGeneratedScorerRequest
from .create_job_request import CreateJobRequest
from .create_job_response import CreateJobResponse
from .create_llm_scorer_version_request import CreateLLMScorerVersionRequest
from .create_metric_critique_request import CreateMetricCritiqueRequest
from .create_metric_critiques_request import CreateMetricCritiquesRequest
from .create_prompt_template_with_version_request_body import CreatePromptTemplateWithVersionRequestBody
from .create_run_response import CreateRunResponse
from .create_scorer_request import CreateScorerRequest
from .create_signup_link_response import CreateSignupLinkResponse
from .create_update_registered_scorer_response import CreateUpdateRegisteredScorerResponse
from .create_user_response import CreateUserResponse
from .current_user_db import CurrentUserDB
from .customized_agentic_workflow_success_gpt_scorer import CustomizedAgenticWorkflowSuccessGPTScorer
from .customized_agentic_workflow_success_gpt_scorer_aggregates_type_0 import (
    CustomizedAgenticWorkflowSuccessGPTScorerAggregatesType0,
)
from .customized_agentic_workflow_success_gpt_scorer_extra_type_0 import (
    CustomizedAgenticWorkflowSuccessGPTScorerExtraType0,
)
from .customized_chunk_attribution_utilization_gpt_scorer import CustomizedChunkAttributionUtilizationGPTScorer
from .customized_chunk_attribution_utilization_gpt_scorer_aggregates_type_0 import (
    CustomizedChunkAttributionUtilizationGPTScorerAggregatesType0,
)
from .customized_chunk_attribution_utilization_gpt_scorer_extra_type_0 import (
    CustomizedChunkAttributionUtilizationGPTScorerExtraType0,
)
from .customized_completeness_gpt_scorer import CustomizedCompletenessGPTScorer
from .customized_completeness_gpt_scorer_aggregates_type_0 import CustomizedCompletenessGPTScorerAggregatesType0
from .customized_completeness_gpt_scorer_extra_type_0 import CustomizedCompletenessGPTScorerExtraType0
from .customized_factuality_gpt_scorer import CustomizedFactualityGPTScorer
from .customized_factuality_gpt_scorer_aggregates_type_0 import CustomizedFactualityGPTScorerAggregatesType0
from .customized_factuality_gpt_scorer_extra_type_0 import CustomizedFactualityGPTScorerExtraType0
from .customized_ground_truth_adherence_gpt_scorer import CustomizedGroundTruthAdherenceGPTScorer
from .customized_ground_truth_adherence_gpt_scorer_aggregates_type_0 import (
    CustomizedGroundTruthAdherenceGPTScorerAggregatesType0,
)
from .customized_ground_truth_adherence_gpt_scorer_extra_type_0 import CustomizedGroundTruthAdherenceGPTScorerExtraType0
from .customized_groundedness_gpt_scorer import CustomizedGroundednessGPTScorer
from .customized_groundedness_gpt_scorer_aggregates_type_0 import CustomizedGroundednessGPTScorerAggregatesType0
from .customized_groundedness_gpt_scorer_extra_type_0 import CustomizedGroundednessGPTScorerExtraType0
from .customized_instruction_adherence_gpt_scorer import CustomizedInstructionAdherenceGPTScorer
from .customized_instruction_adherence_gpt_scorer_aggregates_type_0 import (
    CustomizedInstructionAdherenceGPTScorerAggregatesType0,
)
from .customized_instruction_adherence_gpt_scorer_extra_type_0 import CustomizedInstructionAdherenceGPTScorerExtraType0
from .customized_scorer import CustomizedScorer
from .customized_scorer_name import CustomizedScorerName
from .customized_tool_error_rate_gpt_scorer import CustomizedToolErrorRateGPTScorer
from .customized_tool_error_rate_gpt_scorer_aggregates_type_0 import CustomizedToolErrorRateGPTScorerAggregatesType0
from .customized_tool_error_rate_gpt_scorer_extra_type_0 import CustomizedToolErrorRateGPTScorerExtraType0
from .customized_tool_selection_quality_gpt_scorer import CustomizedToolSelectionQualityGPTScorer
from .customized_tool_selection_quality_gpt_scorer_aggregates_type_0 import (
    CustomizedToolSelectionQualityGPTScorerAggregatesType0,
)
from .customized_tool_selection_quality_gpt_scorer_extra_type_0 import CustomizedToolSelectionQualityGPTScorerExtraType0
from .data_row import DataRow
from .data_row_meta_type_0 import DataRowMetaType0
from .data_row_system_prompts_type_0 import DataRowSystemPromptsType0
from .data_rows import DataRows
from .data_type_options import DataTypeOptions
from .databricks_edit_export_request import DatabricksEditExportRequest
from .databricks_edit_export_request_col_mapping_type_0 import DatabricksEditExportRequestColMappingType0
from .databricks_edit_export_response import DatabricksEditExportResponse
from .databricks_edit_export_response_col_mapping_type_0 import DatabricksEditExportResponseColMappingType0
from .databricks_export_request import DatabricksExportRequest
from .databricks_export_request_col_mapping_type_0 import DatabricksExportRequestColMappingType0
from .databricks_export_response import DatabricksExportResponse
from .databricks_export_response_col_mapping_type_0 import DatabricksExportResponseColMappingType0
from .databricks_integration import DatabricksIntegration
from .databricks_integration_create import DatabricksIntegrationCreate
from .databricks_integration_extra_type_0 import DatabricksIntegrationExtraType0
from .databricks_observe_export_request import DatabricksObserveExportRequest
from .databricks_unity_catalog_edit_export_request import DatabricksUnityCatalogEditExportRequest
from .databricks_unity_catalog_edit_export_request_col_mapping_type_0 import (
    DatabricksUnityCatalogEditExportRequestColMappingType0,
)
from .databricks_unity_catalog_export_edits_response import DatabricksUnityCatalogExportEditsResponse
from .databricks_unity_catalog_export_edits_response_col_mapping_type_0 import (
    DatabricksUnityCatalogExportEditsResponseColMappingType0,
)
from .databricks_unity_catalog_export_response import DatabricksUnityCatalogExportResponse
from .databricks_unity_catalog_export_response_col_mapping_type_0 import (
    DatabricksUnityCatalogExportResponseColMappingType0,
)
from .dataset_action import DatasetAction
from .dataset_add_column import DatasetAddColumn
from .dataset_append_row import DatasetAppendRow
from .dataset_append_row_values import DatasetAppendRowValues
from .dataset_content import DatasetContent
from .dataset_content_filter import DatasetContentFilter
from .dataset_content_filter_operator import DatasetContentFilterOperator
from .dataset_content_sort_clause import DatasetContentSortClause
from .dataset_created_at_sort import DatasetCreatedAtSort
from .dataset_db import DatasetDB
from .dataset_delete_column import DatasetDeleteColumn
from .dataset_delete_row import DatasetDeleteRow
from .dataset_format import DatasetFormat
from .dataset_last_edited_by_user_at_sort import DatasetLastEditedByUserAtSort
from .dataset_name_filter import DatasetNameFilter
from .dataset_name_filter_operator import DatasetNameFilterOperator
from .dataset_name_sort import DatasetNameSort
from .dataset_project_last_used_at_sort import DatasetProjectLastUsedAtSort
from .dataset_projects_sort import DatasetProjectsSort
from .dataset_rename_column import DatasetRenameColumn
from .dataset_row import DatasetRow
from .dataset_rows_sort import DatasetRowsSort
from .dataset_type import DatasetType
from .dataset_update_row import DatasetUpdateRow
from .dataset_update_row_values import DatasetUpdateRowValues
from .dataset_updated_at_sort import DatasetUpdatedAtSort
from .dataset_used_in_project_filter import DatasetUsedInProjectFilter
from .dataset_version_db import DatasetVersionDB
from .dataset_version_index_sort import DatasetVersionIndexSort
from .delete_prompt_response import DeletePromptResponse
from .delete_run_response import DeleteRunResponse
from .delete_runs_request import DeleteRunsRequest
from .delete_runs_response import DeleteRunsResponse
from .delete_user_response import DeleteUserResponse
from .distribution import Distribution
from .distribution_request import DistributionRequest
from .document import Document
from .document_metadata import DocumentMetadata
from .edit_action import EditAction
from .edit_content import EditContent
from .edit_content_edit_spans_type_0 import EditContentEditSpansType0
from .edit_create_request import EditCreateRequest
from .edit_create_request_edit_spans_type_0 import EditCreateRequestEditSpansType0
from .edit_create_response import EditCreateResponse
from .edit_create_response_edit_spans_type_0 import EditCreateResponseEditSpansType0
from .edit_delete_response import EditDeleteResponse
from .edit_export_db import EditExportDB
from .edit_export_request import EditExportRequest
from .edit_export_request_col_mapping_type_0 import EditExportRequestColMappingType0
from .edit_get_response import EditGetResponse
from .edit_get_response_edit_spans_type_0 import EditGetResponseEditSpansType0
from .edit_override import EditOverride
from .edit_override_edit_spans_type_0 import EditOverrideEditSpansType0
from .edit_review_db import EditReviewDB
from .edit_row_data import EditRowData
from .edit_row_data_meta_type_0 import EditRowDataMetaType0
from .edit_span import EditSpan
from .edit_summary import EditSummary
from .email_verification_request import EmailVerificationRequest
from .embedding_data import EmbeddingData
from .embedding_data_meta_type_0 import EmbeddingDataMetaType0
from .embedding_point_request import EmbeddingPointRequest
from .embedding_point_response import EmbeddingPointResponse
from .embedding_request import EmbeddingRequest
from .error_distribution import ErrorDistribution
from .evaluate_alert_db import EvaluateAlertDB
from .evaluate_alert_db_extra_type_0 import EvaluateAlertDBExtraType0
from .evaluate_project_settings import EvaluateProjectSettings
from .evaluate_project_settings_metric_weights_configuration_type_0 import (
    EvaluateProjectSettingsMetricWeightsConfigurationType0,
)
from .evaluate_run_request import EvaluateRunRequest
from .evaluate_run_response import EvaluateRunResponse
from .evaluate_run_results_request import EvaluateRunResultsRequest
from .execution_status import ExecutionStatus
from .experiment_create_request import ExperimentCreateRequest
from .experiment_response import ExperimentResponse
from .experiment_update_request import ExperimentUpdateRequest
from .export_request import ExportRequest
from .export_request_col_mapping_type_0 import ExportRequestColMappingType0
from .extra_alert_filters import ExtraAlertFilters
from .factuality_template import FactualityTemplate
from .feature_columns_response import FeatureColumnsResponse
from .feedback_aggregate import FeedbackAggregate
from .feedback_rating_create import FeedbackRatingCreate
from .feedback_rating_db import FeedbackRatingDB
from .feedback_rating_operation_type import FeedbackRatingOperationType
from .feedback_template_create import FeedbackTemplateCreate
from .feedback_template_db import FeedbackTemplateDB
from .feedback_template_update import FeedbackTemplateUpdate
from .few_shot_example import FewShotExample
from .field_type import FieldType
from .file_type import FileType
from .filter_options_response import FilterOptionsResponse
from .filter_options_response_filter_options import FilterOptionsResponseFilterOptions
from .filter_params import FilterParams
from .filter_percentage_request import FilterPercentageRequest
from .filter_percentage_response import FilterPercentageResponse
from .filters_request_body import FiltersRequestBody
from .gen_ai_project_settings import GenAIProjectSettings
from .generated_scorer import GeneratedScorer
from .generated_scorer_action import GeneratedScorerAction
from .generated_scorer_config import GeneratedScorerConfig
from .generated_scorer_configuration import GeneratedScorerConfiguration
from .generated_scorer_response import GeneratedScorerResponse
from .generated_scorer_task_result_response import GeneratedScorerTaskResultResponse
from .generated_scorer_task_result_status import GeneratedScorerTaskResultStatus
from .generated_scorer_task_result_type import GeneratedScorerTaskResultType
from .generated_scorer_validation_request import GeneratedScorerValidationRequest
from .generated_scorer_validation_response import GeneratedScorerValidationResponse
from .generated_scorer_validation_result import GeneratedScorerValidationResult
from .generation_request import GenerationRequest
from .generation_response import GenerationResponse
from .generic_action import GenericAction
from .generic_permission import GenericPermission
from .get_api_key_response import GetApiKeyResponse
from .get_integration_status_integrations_name_status_get_response_get_integration_status_integrations_name_status_get import (
    GetIntegrationStatusIntegrationsNameStatusGetResponseGetIntegrationStatusIntegrationsNameStatusGet,
)
from .get_metrics_schema_endpoint_projects_project_id_observe_column_schema_get_response_get_metrics_schema_endpoint_projects_project_id_observe_column_schema_get import (
    GetMetricsSchemaEndpointProjectsProjectIdObserveColumnSchemaGetResponseGetMetricsSchemaEndpointProjectsProjectIdObserveColumnSchemaGet,
)
from .get_multi_run_samples_for_row_ids_projects_project_id_runs_prompts_rows_columnar_post_response_get_multi_run_samples_for_row_ids_projects_project_id_runs_prompts_rows_columnar_post import (
    GetMultiRunSamplesForRowIdsProjectsProjectIdRunsPromptsRowsColumnarPostResponseGetMultiRunSamplesForRowIdsProjectsProjectIdRunsPromptsRowsColumnarPost,
)
from .get_multi_run_samples_for_row_ids_projects_project_id_runs_prompts_rows_columnar_post_row_ids import (
    GetMultiRunSamplesForRowIdsProjectsProjectIdRunsPromptsRowsColumnarPostRowIds,
)
from .get_observe_workflows_request import GetObserveWorkflowsRequest
from .get_presigned_url_response import GetPresignedUrlResponse
from .get_projects_paginated_response import GetProjectsPaginatedResponse
from .get_prompt_rows_columnar_response import GetPromptRowsColumnarResponse
from .get_prompt_rows_response import GetPromptRowsResponse
from .get_prompt_run import GetPromptRun
from .get_prompt_run_columns_response import GetPromptRunColumnsResponse
from .get_prompt_run_metrics import GetPromptRunMetrics
from .get_prompt_runs_response import GetPromptRunsResponse
from .get_splits_response import GetSplitsResponse
from .get_token_for_training_job_training_training_job_id_token_post_request_body import (
    GetTokenForTrainingJobTrainingTrainingJobIdTokenPostRequestBody,
)
from .get_token_response import GetTokenResponse
from .get_usage_plans_usage_plans_get_response_get_usage_plans_usage_plans_get import (
    GetUsagePlansUsagePlansGetResponseGetUsagePlansUsagePlansGet,
)
from .get_user_latest_runs_db import GetUserLatestRunsDB
from .get_user_response import GetUserResponse
from .get_users_response import GetUsersResponse
from .ground_truth_adherence_scorer import GroundTruthAdherenceScorer
from .ground_truth_adherence_template import GroundTruthAdherenceTemplate
from .groundedness_template import GroundednessTemplate
from .group_action import GroupAction
from .group_by_metrics import GroupByMetrics
from .group_collaborator import GroupCollaborator
from .group_collaborator_create import GroupCollaboratorCreate
from .group_create import GroupCreate
from .group_db import GroupDB
from .group_label import GroupLabel
from .group_member_action import GroupMemberAction
from .group_member_create import GroupMemberCreate
from .group_member_db import GroupMemberDB
from .group_member_update import GroupMemberUpdate
from .group_role import GroupRole
from .group_role_info import GroupRoleInfo
from .group_update import GroupUpdate
from .group_visibility import GroupVisibility
from .hallucination_segment import HallucinationSegment
from .has_embeddings_response import HasEmbeddingsResponse
from .healthcheck_response import HealthcheckResponse
from .http_validation_error import HTTPValidationError
from .index_selector import IndexSelector
from .inference_model_metrics import InferenceModelMetrics
from .inference_names_response import InferenceNamesResponse
from .inference_results import InferenceResults
from .inference_run_results import InferenceRunResults
from .input_map import InputMap
from .input_pii_scorer import InputPIIScorer
from .input_sexist_scorer import InputSexistScorer
from .input_tone_scorer import InputToneScorer
from .input_toxicity_scorer import InputToxicityScorer
from .insight_chart_request import InsightChartRequest
from .insight_chart_response import InsightChartResponse
from .insight_type import InsightType
from .instruction_adherence_scorer import InstructionAdherenceScorer
from .instruction_adherence_template import InstructionAdherenceTemplate
from .integration_db import IntegrationDB
from .integration_name import IntegrationName
from .invite_users_request import InviteUsersRequest
from .invoke_response import InvokeResponse
from .invoke_response_headers_type_0 import InvokeResponseHeadersType0
from .invoke_response_metadata_type_0 import InvokeResponseMetadataType0
from .invoke_response_metric_results import InvokeResponseMetricResults
from .job_db import JobDB
from .job_db_request_data import JobDBRequestData
from .job_info import JobInfo
from .job_status import JobStatus
from .label_co_occurences import LabelCoOccurences
from .label_response import LabelResponse
from .label_studio_export_request import LabelStudioExportRequest
from .label_studio_integration import LabelStudioIntegration
from .label_studio_integration_create import LabelStudioIntegrationCreate
from .label_studio_integration_extra_type_0 import LabelStudioIntegrationExtraType0
from .label_studio_project import LabelStudioProject
from .lasso_selection import LassoSelection
from .like_dislike_aggregate import LikeDislikeAggregate
from .like_dislike_constraints import LikeDislikeConstraints
from .like_dislike_rating import LikeDislikeRating
from .list_alert_configurations_response import ListAlertConfigurationsResponse
from .list_api_key_response import ListApiKeyResponse
from .list_dataset_params import ListDatasetParams
from .list_dataset_response import ListDatasetResponse
from .list_dataset_version_params import ListDatasetVersionParams
from .list_dataset_version_response import ListDatasetVersionResponse
from .list_generated_scorers_response import ListGeneratedScorersResponse
from .list_group_collaborators_response import ListGroupCollaboratorsResponse
from .list_group_members_response import ListGroupMembersResponse
from .list_groups_response import ListGroupsResponse
from .list_meta_request import ListMetaRequest
from .list_meta_response import ListMetaResponse
from .list_organizations_response import ListOrganizationsResponse
from .list_prompt_dataset_response import ListPromptDatasetResponse
from .list_registered_scorers_response import ListRegisteredScorersResponse
from .list_scorers_request import ListScorersRequest
from .list_scorers_response import ListScorersResponse
from .list_user_collaborators_response import ListUserCollaboratorsResponse
from .llm_export_format import LLMExportFormat
from .llm_integration import LLMIntegration
from .llm_span import LlmSpan
from .llm_span_input_type_3 import LlmSpanInputType3
from .llm_span_input_type_7_item import LlmSpanInputType7Item
from .llm_span_input_type_8_item import LlmSpanInputType8Item
from .llm_span_metadata import LlmSpanMetadata
from .llm_span_output_type_3 import LlmSpanOutputType3
from .llm_span_output_type_7_item import LlmSpanOutputType7Item
from .llm_span_output_type_8_item import LlmSpanOutputType8Item
from .llm_span_tools_type_0_item import LlmSpanToolsType0Item
from .llm_span_with_metrics import LlmSpanWithMetrics
from .llm_span_with_metrics_input_type_3 import LlmSpanWithMetricsInputType3
from .llm_span_with_metrics_input_type_7_item import LlmSpanWithMetricsInputType7Item
from .llm_span_with_metrics_input_type_8_item import LlmSpanWithMetricsInputType8Item
from .llm_span_with_metrics_metadata import LlmSpanWithMetricsMetadata
from .llm_span_with_metrics_metrics import LlmSpanWithMetricsMetrics
from .llm_span_with_metrics_output_type_3 import LlmSpanWithMetricsOutputType3
from .llm_span_with_metrics_output_type_7_item import LlmSpanWithMetricsOutputType7Item
from .llm_span_with_metrics_output_type_8_item import LlmSpanWithMetricsOutputType8Item
from .llm_span_with_metrics_tools_type_0_item import LlmSpanWithMetricsToolsType0Item
from .llm_step import LlmStep
from .llm_step_input_type_1 import LlmStepInputType1
from .llm_step_input_type_4_item import LlmStepInputType4Item
from .llm_step_metadata import LlmStepMetadata
from .llm_step_output_type_1 import LlmStepOutputType1
from .llm_step_output_type_4_item import LlmStepOutputType4Item
from .llm_step_tools_type_0_item import LlmStepToolsType0Item
from .log_data_available_columns_request import LogDataAvailableColumnsRequest
from .log_data_available_columns_response import LogDataAvailableColumnsResponse
from .log_data_column_info import LogDataColumnInfo
from .log_data_id_column_filter import LogDataIDColumnFilter
from .log_data_logging_method import LogDataLoggingMethod
from .log_data_node_type_filter import LogDataNodeTypeFilter
from .log_data_node_type_filter_operator import LogDataNodeTypeFilterOperator
from .log_data_query_request import LogDataQueryRequest
from .log_data_query_response import LogDataQueryResponse
from .log_stream_create_request import LogStreamCreateRequest
from .log_stream_response import LogStreamResponse
from .log_stream_update_request import LogStreamUpdateRequest
from .map_response import MAPResponse
from .message import Message
from .message_role import MessageRole
from .meta_filter import MetaFilter
from .meta_info import MetaInfo
from .metadata_filter import MetadataFilter
from .metadata_filter_operator import MetadataFilterOperator
from .method import Method
from .metric_computation import MetricComputation
from .metric_computation_status import MetricComputationStatus
from .metric_computation_value_type_4 import MetricComputationValueType4
from .metric_computing import MetricComputing
from .metric_critique import MetricCritique
from .metric_critique_column import MetricCritiqueColumn
from .metric_critique_columnar import MetricCritiqueColumnar
from .metric_critique_columns import MetricCritiqueColumns
from .metric_critique_content import MetricCritiqueContent
from .metric_critique_job_configuration import MetricCritiqueJobConfiguration
from .metric_descriptions import MetricDescriptions
from .metric_error import MetricError
from .metric_failed import MetricFailed
from .metric_inputs import MetricInputs
from .metric_insight import MetricInsight
from .metric_insight_categories import MetricInsightCategories
from .metric_not_applicable import MetricNotApplicable
from .metric_not_computed import MetricNotComputed
from .metric_pending import MetricPending
from .metric_success import MetricSuccess
from .metric_threshold import MetricThreshold
from .metric_weight import MetricWeight
from .metrics import Metrics
from .metrics_request import MetricsRequest
from .metrics_response import MetricsResponse
from .mistral_integration import MistralIntegration
from .mistral_integration_create import MistralIntegrationCreate
from .mistral_integration_extra_type_0 import MistralIntegrationExtraType0
from .model import Model
from .model_cost_by import ModelCostBy
from .model_info import ModelInfo
from .model_kind import ModelKind
from .model_metrics import ModelMetrics
from .model_type import ModelType
from .model_upload_status import ModelUploadStatus
from .multi_label_co_occurrence import MultiLabelCoOccurrence
from .multi_label_task_metrics import MultiLabelTaskMetrics
from .node_name_filter import NodeNameFilter
from .node_name_filter_operator import NodeNameFilterOperator
from .node_type import NodeType
from .noise_type import NoiseType
from .observe_project_settings import ObserveProjectSettings
from .open_ai_function import OpenAIFunction
from .open_ai_integration import OpenAIIntegration
from .open_ai_integration_create import OpenAIIntegrationCreate
from .open_ai_integration_extra_type_0 import OpenAIIntegrationExtraType0
from .open_ai_tool_choice import OpenAIToolChoice
from .operator import Operator
from .organization_action import OrganizationAction
from .organization_create import OrganizationCreate
from .organization_created_at_sort import OrganizationCreatedAtSort
from .organization_db import OrganizationDB
from .organization_is_member_filter import OrganizationIsMemberFilter
from .organization_name_filter import OrganizationNameFilter
from .organization_name_filter_operator import OrganizationNameFilterOperator
from .organization_name_sort import OrganizationNameSort
from .output_map import OutputMap
from .output_pii_scorer import OutputPIIScorer
from .output_sexist_scorer import OutputSexistScorer
from .output_tone_scorer import OutputToneScorer
from .output_toxicity_scorer import OutputToxicityScorer
from .override_action import OverrideAction
from .passthrough_action import PassthroughAction
from .password_reset_email_response import PasswordResetEmailResponse
from .password_reset_response import PasswordResetResponse
from .payload import Payload
from .permission import Permission
from .polygon_data import PolygonData
from .polygon_size import PolygonSize
from .project_action import ProjectAction
from .project_bookmark_filter import ProjectBookmarkFilter
from .project_bookmark_sort import ProjectBookmarkSort
from .project_collection_params import ProjectCollectionParams
from .project_create import ProjectCreate
from .project_create_response import ProjectCreateResponse
from .project_created_at_filter import ProjectCreatedAtFilter
from .project_created_at_filter_operator import ProjectCreatedAtFilterOperator
from .project_created_at_sort import ProjectCreatedAtSort
from .project_creator_filter import ProjectCreatorFilter
from .project_db import ProjectDB
from .project_db_thin import ProjectDBThin
from .project_delete_response import ProjectDeleteResponse
from .project_id_filter import ProjectIDFilter
from .project_integration import ProjectIntegration
from .project_integrations_response import ProjectIntegrationsResponse
from .project_integrations_response_integrations import ProjectIntegrationsResponseIntegrations
from .project_name_filter import ProjectNameFilter
from .project_name_filter_operator import ProjectNameFilterOperator
from .project_name_sort import ProjectNameSort
from .project_run_summary import ProjectRunSummary
from .project_runs_filter import ProjectRunsFilter
from .project_runs_filter_operator import ProjectRunsFilterOperator
from .project_runs_sort import ProjectRunsSort
from .project_settings_db import ProjectSettingsDB
from .project_settings_db_metric_weights_configuration_type_0 import ProjectSettingsDBMetricWeightsConfigurationType0
from .project_type import ProjectType
from .project_type_filter import ProjectTypeFilter
from .project_type_filter_operator import ProjectTypeFilterOperator
from .project_type_sort import ProjectTypeSort
from .project_update import ProjectUpdate
from .project_update_response import ProjectUpdateResponse
from .project_updated_at_filter import ProjectUpdatedAtFilter
from .project_updated_at_filter_operator import ProjectUpdatedAtFilterOperator
from .project_updated_at_sort import ProjectUpdatedAtSort
from .prompt_chain_ingest_batch_request import PromptChainIngestBatchRequest
from .prompt_chain_ingest_batch_response import PromptChainIngestBatchResponse
from .prompt_chain_ingest_request import PromptChainIngestRequest
from .prompt_chain_ingest_response import PromptChainIngestResponse
from .prompt_dataset_db import PromptDatasetDB
from .prompt_filter_params import PromptFilterParams
from .prompt_group_response import PromptGroupResponse
from .prompt_injection_scorer import PromptInjectionScorer
from .prompt_optimization_configuration import PromptOptimizationConfiguration
from .prompt_perplexity_scorer import PromptPerplexityScorer
from .prompt_row import PromptRow
from .prompt_row_column import PromptRowColumn
from .prompt_row_inputs import PromptRowInputs
from .prompt_row_node_output_type_2 import PromptRowNodeOutputType2
from .prompt_run_column import PromptRunColumn
from .prompt_run_settings import PromptRunSettings
from .prompt_run_settings_response_format_type_0 import PromptRunSettingsResponseFormatType0
from .prompt_run_settings_tools_type_0_item import PromptRunSettingsToolsType0Item
from .prompt_sample_i_ds import PromptSampleIDs
from .prompt_sample_i_ds_sample_indices import PromptSampleIDsSampleIndices
from .put_prompt_score_request import PutPromptScoreRequest
from .put_prompt_score_request_aggregates_type_0 import PutPromptScoreRequestAggregatesType0
from .put_prompt_score_response import PutPromptScoreResponse
from .query_dataset_params import QueryDatasetParams
from .query_filter_v1 import QueryFilterV1
from .query_organization_params import QueryOrganizationParams
from .range_prompt_filter_param import RangePromptFilterParam
from .recompute_settings_observe import RecomputeSettingsObserve
from .recompute_settings_observe_base import RecomputeSettingsObserveBase
from .recompute_settings_project import RecomputeSettingsProject
from .recompute_settings_runs import RecomputeSettingsRuns
from .registered_scorer import RegisteredScorer
from .registered_scorer_action import RegisteredScorerAction
from .registered_scorer_config import RegisteredScorerConfig
from .remote_edit_export_request import RemoteEditExportRequest
from .remote_edit_export_request_col_mapping_type_0 import RemoteEditExportRequestColMappingType0
from .remote_edit_export_response import RemoteEditExportResponse
from .remote_edit_export_response_col_mapping_type_0 import RemoteEditExportResponseColMappingType0
from .remote_export_request import RemoteExportRequest
from .remote_export_request_col_mapping_type_0 import RemoteExportRequestColMappingType0
from .remote_export_response import RemoteExportResponse
from .remote_export_response_col_mapping_type_0 import RemoteExportResponseColMappingType0
from .request import Request
from .request_headers_type_0 import RequestHeadersType0
from .request_metadata_type_0 import RequestMetadataType0
from .resource_kind import ResourceKind
from .response import Response
from .retriever_span import RetrieverSpan
from .retriever_span_input_type_3 import RetrieverSpanInputType3
from .retriever_span_input_type_7_item import RetrieverSpanInputType7Item
from .retriever_span_input_type_8_item import RetrieverSpanInputType8Item
from .retriever_span_metadata import RetrieverSpanMetadata
from .retriever_span_output_type_3 import RetrieverSpanOutputType3
from .retriever_span_output_type_7_item import RetrieverSpanOutputType7Item
from .retriever_span_output_type_8_item import RetrieverSpanOutputType8Item
from .retriever_span_with_metrics import RetrieverSpanWithMetrics
from .retriever_span_with_metrics_input_type_3 import RetrieverSpanWithMetricsInputType3
from .retriever_span_with_metrics_input_type_7_item import RetrieverSpanWithMetricsInputType7Item
from .retriever_span_with_metrics_input_type_8_item import RetrieverSpanWithMetricsInputType8Item
from .retriever_span_with_metrics_metadata import RetrieverSpanWithMetricsMetadata
from .retriever_span_with_metrics_metrics import RetrieverSpanWithMetricsMetrics
from .retriever_span_with_metrics_output_type_3 import RetrieverSpanWithMetricsOutputType3
from .retriever_span_with_metrics_output_type_7_item import RetrieverSpanWithMetricsOutputType7Item
from .retriever_span_with_metrics_output_type_8_item import RetrieverSpanWithMetricsOutputType8Item
from .retriever_step import RetrieverStep
from .retriever_step_metadata import RetrieverStepMetadata
from .rollback_request import RollbackRequest
from .rouge_scorer import RougeScorer
from .rule import Rule
from .rule_operator import RuleOperator
from .rule_result import RuleResult
from .ruleset import Ruleset
from .ruleset_result import RulesetResult
from .rulesets_mixin import RulesetsMixin
from .run_create import RunCreate
from .run_db import RunDB
from .run_db_thin import RunDBThin
from .run_db_thin_with_project_name import RunDBThinWithProjectName
from .run_link_response import RunLinkResponse
from .run_metric_create_request import RunMetricCreateRequest
from .run_metric_create_request_extra_type_1 import RunMetricCreateRequestExtraType1
from .run_metric_db import RunMetricDB
from .run_metric_db_extra_type_1 import RunMetricDBExtraType1
from .run_params_map import RunParamsMap
from .run_results import RunResults
from .run_results_top_erroneous_words_type_0 import RunResultsTopErroneousWordsType0
from .run_scorer_settings_request import RunScorerSettingsRequest
from .run_tag_create_request import RunTagCreateRequest
from .run_tag_db import RunTagDB
from .run_update_request import RunUpdateRequest
from .score_aggregate import ScoreAggregate
from .score_constraints import ScoreConstraints
from .score_rating import ScoreRating
from .scorer_config import ScorerConfig
from .scorer_created_at_filter import ScorerCreatedAtFilter
from .scorer_created_at_filter_operator import ScorerCreatedAtFilterOperator
from .scorer_creator_filter import ScorerCreatorFilter
from .scorer_defaults import ScorerDefaults
from .scorer_name import ScorerName
from .scorer_name_filter import ScorerNameFilter
from .scorer_name_filter_operator import ScorerNameFilterOperator
from .scorer_response import ScorerResponse
from .scorer_tags_filter import ScorerTagsFilter
from .scorer_tags_filter_operator import ScorerTagsFilterOperator
from .scorer_type import ScorerType
from .scorer_type_filter import ScorerTypeFilter
from .scorer_type_filter_operator import ScorerTypeFilterOperator
from .scorer_types import ScorerTypes
from .scorer_updated_at_filter import ScorerUpdatedAtFilter
from .scorer_updated_at_filter_operator import ScorerUpdatedAtFilterOperator
from .scorer_version_response import ScorerVersionResponse
from .scorer_versions_response import ScorerVersionsResponse
from .scorers_config import ScorersConfig
from .scorers_configuration import ScorersConfiguration
from .segment import Segment
from .segmentation_metrics_response import SegmentationMetricsResponse
from .sem_seg_error_type import SemSegErrorType
from .seq_2_seq_metrics_response import Seq2SeqMetricsResponse
from .seq_2_seq_segment import Seq2SeqSegment
from .similar_to_response import SimilarToResponse
from .slice_create import SliceCreate
from .slice_create_response import SliceCreateResponse
from .slice_db import SliceDB
from .slice_delete_response import SliceDeleteResponse
from .slice_metrics import SliceMetrics
from .slice_update import SliceUpdate
from .slice_update_response import SliceUpdateResponse
from .social_login_request import SocialLoginRequest
from .social_provider import SocialProvider
from .sort_clause import SortClause
from .sort_direction import SortDirection
from .span import Span
from .split import Split
from .split_run_results import SplitRunResults
from .stage_db import StageDB
from .stage_metadata import StageMetadata
from .stage_type import StageType
from .stage_with_rulesets import StageWithRulesets
from .standard_column_sort import StandardColumnSort
from .star_aggregate import StarAggregate
from .star_aggregate_counts import StarAggregateCounts
from .star_constraints import StarConstraints
from .star_rating import StarRating
from .start_training_job_projects_project_id_training_mode_start_post_request_body import (
    StartTrainingJobProjectsProjectIdTrainingModeStartPostRequestBody,
)
from .step_metric import StepMetric
from .step_with_child_spans import StepWithChildSpans
from .step_with_child_spans_input_type_3 import StepWithChildSpansInputType3
from .step_with_child_spans_input_type_7_item import StepWithChildSpansInputType7Item
from .step_with_child_spans_input_type_8_item import StepWithChildSpansInputType8Item
from .step_with_child_spans_metadata import StepWithChildSpansMetadata
from .step_with_child_spans_output_type_3 import StepWithChildSpansOutputType3
from .step_with_child_spans_output_type_7_item import StepWithChildSpansOutputType7Item
from .step_with_child_spans_output_type_8_item import StepWithChildSpansOutputType8Item
from .step_with_children import StepWithChildren
from .step_with_children_input_type_3 import StepWithChildrenInputType3
from .step_with_children_input_type_7_item import StepWithChildrenInputType7Item
from .step_with_children_input_type_8_item import StepWithChildrenInputType8Item
from .step_with_children_metadata import StepWithChildrenMetadata
from .step_with_children_output_type_3 import StepWithChildrenOutputType3
from .step_with_children_output_type_7_item import StepWithChildrenOutputType7Item
from .step_with_children_output_type_8_item import StepWithChildrenOutputType8Item
from .subscription_config import SubscriptionConfig
from .summary_id_request import SummaryIDRequest
from .summary_id_response import SummaryIDResponse
from .summary_request import SummaryRequest
from .tagging_schema import TaggingSchema
from .tags_aggregate import TagsAggregate
from .tags_aggregate_counts import TagsAggregateCounts
from .tags_constraints import TagsConstraints
from .tags_rating import TagsRating
from .target_labels import TargetLabels
from .task_response import TaskResponse
from .task_type import TaskType
from .text_constraints import TextConstraints
from .text_rating import TextRating
from .threshold_request import ThresholdRequest
from .threshold_response import ThresholdResponse
from .token import Token
from .tool_error_rate_scorer import ToolErrorRateScorer
from .tool_error_rate_template import ToolErrorRateTemplate
from .tool_selection_quality_scorer import ToolSelectionQualityScorer
from .tool_selection_quality_template import ToolSelectionQualityTemplate
from .tool_span import ToolSpan
from .tool_span_input_type_3 import ToolSpanInputType3
from .tool_span_input_type_7_item import ToolSpanInputType7Item
from .tool_span_input_type_8_item import ToolSpanInputType8Item
from .tool_span_metadata import ToolSpanMetadata
from .tool_span_output_type_3 import ToolSpanOutputType3
from .tool_span_output_type_7_item import ToolSpanOutputType7Item
from .tool_span_output_type_8_item import ToolSpanOutputType8Item
from .tool_span_with_metrics import ToolSpanWithMetrics
from .tool_span_with_metrics_input_type_3 import ToolSpanWithMetricsInputType3
from .tool_span_with_metrics_input_type_7_item import ToolSpanWithMetricsInputType7Item
from .tool_span_with_metrics_input_type_8_item import ToolSpanWithMetricsInputType8Item
from .tool_span_with_metrics_metadata import ToolSpanWithMetricsMetadata
from .tool_span_with_metrics_metrics import ToolSpanWithMetricsMetrics
from .tool_span_with_metrics_output_type_3 import ToolSpanWithMetricsOutputType3
from .tool_span_with_metrics_output_type_7_item import ToolSpanWithMetricsOutputType7Item
from .tool_span_with_metrics_output_type_8_item import ToolSpanWithMetricsOutputType8Item
from .tool_step import ToolStep
from .tool_step_input_type_3 import ToolStepInputType3
from .tool_step_input_type_7_item import ToolStepInputType7Item
from .tool_step_input_type_8_item import ToolStepInputType8Item
from .tool_step_metadata import ToolStepMetadata
from .tool_step_output_type_3 import ToolStepOutputType3
from .tool_step_output_type_7_item import ToolStepOutputType7Item
from .tool_step_output_type_8_item import ToolStepOutputType8Item
from .top_insights_request import TopInsightsRequest
from .top_insights_response import TopInsightsResponse
from .top_insights_response_top_correlation_pairs import TopInsightsResponseTopCorrelationPairs
from .top_insights_response_top_erroneous_words import TopInsightsResponseTopErroneousWords
from .top_insights_response_top_misclassified_pairs_item import TopInsightsResponseTopMisclassifiedPairsItem
from .top_k_token import TopKToken
from .trace import Trace
from .trace_input_type_3 import TraceInputType3
from .trace_input_type_7_item import TraceInputType7Item
from .trace_input_type_8_item import TraceInputType8Item
from .trace_metadata import TraceMetadata
from .trace_output_type_3 import TraceOutputType3
from .trace_output_type_7_item import TraceOutputType7Item
from .trace_output_type_8_item import TraceOutputType8Item
from .trace_trace_metadata import TraceTraceMetadata
from .trace_with_metrics import TraceWithMetrics
from .trace_with_metrics_input_type_3 import TraceWithMetricsInputType3
from .trace_with_metrics_input_type_7_item import TraceWithMetricsInputType7Item
from .trace_with_metrics_input_type_8_item import TraceWithMetricsInputType8Item
from .trace_with_metrics_metadata import TraceWithMetricsMetadata
from .trace_with_metrics_metrics import TraceWithMetricsMetrics
from .trace_with_metrics_output_type_3 import TraceWithMetricsOutputType3
from .trace_with_metrics_output_type_7_item import TraceWithMetricsOutputType7Item
from .trace_with_metrics_output_type_8_item import TraceWithMetricsOutputType8Item
from .traces_ingest_request import TracesIngestRequest
from .traces_ingest_response import TracesIngestResponse
from .train_job_auth_token_response import TrainJobAuthTokenResponse
from .train_job_status_response import TrainJobStatusResponse
from .train_response import TrainResponse
from .training_model_response import TrainingModelResponse
from .training_model_response_parameters import TrainingModelResponseParameters
from .transaction_logging_method import TransactionLoggingMethod
from .transaction_metrics_response import TransactionMetricsResponse
from .transaction_metrics_response_bucketed_metrics import TransactionMetricsResponseBucketedMetrics
from .transaction_record_batch import TransactionRecordBatch
from .transaction_record_db_output_logprobs_type_0 import TransactionRecordDBOutputLogprobsType0
from .transaction_record_db_user_metadata_type_0 import TransactionRecordDBUserMetadataType0
from .transaction_record_ingest import TransactionRecordIngest
from .transaction_record_ingest_output_logprobs_type_0 import TransactionRecordIngestOutputLogprobsType0
from .transaction_record_ingest_user_metadata_type_0 import TransactionRecordIngestUserMetadataType0
from .transaction_record_status import TransactionRecordStatus
from .transaction_rows_request_body import TransactionRowsRequestBody
from .transfer_user_response import TransferUserResponse
from .uncertainty_scorer import UncertaintyScorer
from .update_alert_configuration_request import UpdateAlertConfigurationRequest
from .update_dataset_content_request import UpdateDatasetContentRequest
from .update_dataset_request import UpdateDatasetRequest
from .update_dataset_version_request import UpdateDatasetVersionRequest
from .update_generated_scorer_request import UpdateGeneratedScorerRequest
from .update_run_response import UpdateRunResponse
from .update_scorer_request import UpdateScorerRequest
from .update_user_response import UpdateUserResponse
from .upload_model import UploadModel
from .upload_model_parameters import UploadModelParameters
from .upload_model_response import UploadModelResponse
from .usage_plan import UsagePlan
from .usage_plan_name import UsagePlanName
from .user_action import UserAction
from .user_collaborator import UserCollaborator
from .user_collaborator_create import UserCollaboratorCreate
from .user_create import UserCreate
from .user_db import UserDB
from .user_info import UserInfo
from .user_metadata_filter import UserMetadataFilter
from .user_metadata_filter_operator import UserMetadataFilterOperator
from .user_password_reset_request import UserPasswordResetRequest
from .user_password_reset_response import UserPasswordResetResponse
from .user_role import UserRole
from .user_role_info import UserRoleInfo
from .user_update import UserUpdate
from .validation_error import ValidationError
from .validation_request import ValidationRequest
from .validation_response import ValidationResponse
from .value_prompt_filter_param import ValuePromptFilterParam
from .vertex_ai_integration import VertexAIIntegration
from .vertex_ai_integration_create import VertexAIIntegrationCreate
from .vertex_ai_integration_extra_type_0 import VertexAIIntegrationExtraType0
from .webhook import Webhook
from .webhook_status import WebhookStatus
from .weekly_changelog import WeeklyChangelog
from .weekly_changelog_changes import WeeklyChangelogChanges
from .workflow_count_response import WorkflowCountResponse
from .workflow_span import WorkflowSpan
from .workflow_span_input_type_3 import WorkflowSpanInputType3
from .workflow_span_input_type_7_item import WorkflowSpanInputType7Item
from .workflow_span_input_type_8_item import WorkflowSpanInputType8Item
from .workflow_span_metadata import WorkflowSpanMetadata
from .workflow_span_output_type_3 import WorkflowSpanOutputType3
from .workflow_span_output_type_7_item import WorkflowSpanOutputType7Item
from .workflow_span_output_type_8_item import WorkflowSpanOutputType8Item
from .workflow_span_with_metrics import WorkflowSpanWithMetrics
from .workflow_span_with_metrics_input_type_3 import WorkflowSpanWithMetricsInputType3
from .workflow_span_with_metrics_input_type_7_item import WorkflowSpanWithMetricsInputType7Item
from .workflow_span_with_metrics_input_type_8_item import WorkflowSpanWithMetricsInputType8Item
from .workflow_span_with_metrics_metadata import WorkflowSpanWithMetricsMetadata
from .workflow_span_with_metrics_metrics import WorkflowSpanWithMetricsMetrics
from .workflow_span_with_metrics_output_type_3 import WorkflowSpanWithMetricsOutputType3
from .workflow_span_with_metrics_output_type_7_item import WorkflowSpanWithMetricsOutputType7Item
from .workflow_span_with_metrics_output_type_8_item import WorkflowSpanWithMetricsOutputType8Item
from .workflow_step import WorkflowStep
from .workflow_step_input_type_3 import WorkflowStepInputType3
from .workflow_step_input_type_7_item import WorkflowStepInputType7Item
from .workflow_step_input_type_8_item import WorkflowStepInputType8Item
from .workflow_step_metadata import WorkflowStepMetadata
from .workflow_step_output_type_3 import WorkflowStepOutputType3
from .workflow_step_output_type_7_item import WorkflowStepOutputType7Item
from .workflow_step_output_type_8_item import WorkflowStepOutputType8Item
from .workflows_ingest_request import WorkflowsIngestRequest
from .workflows_ingest_response import WorkflowsIngestResponse
from .workflows_read_response import WorkflowsReadResponse
from .writer_integration import WriterIntegration
from .writer_integration_create import WriterIntegrationCreate
from .writer_integration_extra_type_0 import WriterIntegrationExtraType0
from .x_ray_card_db import XRayCardDB
from .x_ray_card_db_message_fields import XRayCardDBMessageFields
from .x_ray_class import XRayClass

__all__ = (
    "ActionResult",
    "ActionType",
    "AgenticWorkflowSuccessScorer",
    "AgenticWorkflowSuccessTemplate",
    "AgentStep",
    "AgentStepInputType3",
    "AgentStepInputType7Item",
    "AgentStepInputType8Item",
    "AgentStepMetadata",
    "AgentStepOutputType3",
    "AgentStepOutputType7Item",
    "AgentStepOutputType8Item",
    "AggregateMetrics",
    "Aggregator",
    "Alert",
    "AlertCondition",
    "AlertConditionType",
    "AlertConfigurationResponse",
    "AlertImportance",
    "AlertMonitorType",
    "AlertsConfiguration",
    "AlertStatusResponse",
    "AnthropicIntegration",
    "AnthropicIntegrationCreate",
    "AnthropicIntegrationExtraType0",
    "ApiKeyAction",
    "ApiKeyDeleteResponse",
    "ApiKeyLoginRequest",
    "AuthMethod",
    "AutoGenResult",
    "AvailableIntegrations",
    "AwsBedrockIntegration",
    "AwsBedrockIntegrationExtraType0",
    "AwsCredentialType",
    "AwsSageMakerIntegration",
    "AwsSageMakerIntegrationCreate",
    "AwsSageMakerIntegrationCreateToken",
    "AwsSageMakerIntegrationExtraType0",
    "AzureAuthenticationType",
    "AzureIntegration",
    "AzureIntegrationCreate",
    "AzureIntegrationCreateHeadersType0",
    "AzureIntegrationExtraType0",
    "AzureIntegrationHeadersType0",
    "AzureModelDeployment",
    "BarChart",
    "BaseAwsIntegrationCreate",
    "BaseAwsIntegrationCreateToken",
    "BaseGalileoStep",
    "BaseGalileoStepInputType3",
    "BaseGalileoStepInputType7Item",
    "BaseGalileoStepInputType8Item",
    "BaseGalileoStepMetadata",
    "BaseGalileoStepOutputType3",
    "BaseGalileoStepOutputType7Item",
    "BaseGalileoStepOutputType8Item",
    "BasePromptTemplateResponse",
    "BasePromptTemplateVersion",
    "BasePromptTemplateVersionResponse",
    "BaseScorer",
    "BaseScorerAggregatesType0",
    "BaseScorerExtraType0",
    "BaseScorerVersionResponse",
    "BBox",
    "BleuScorer",
    "BodyCreateOrUpdateRegisteredScorersPut",
    "BodyLoginEmailLoginPost",
    "BodyUpdatePromptDatasetProjectsProjectIdPromptDatasetsDatasetIdPut",
    "BodyUploadDatasetDatasetsPost",
    "BodyUploadFileProjectsProjectIdUploadFilePost",
    "BodyUploadPromptEvaluationDatasetProjectsProjectIdPromptDatasetsPost",
    "BucketedMetrics",
    "BulkFeedbackRatingCreate",
    "BulkFeedbackRatingDelete",
    "BulkFeedbackRatingStatus",
    "BulkFeedbackRequest",
    "CartographCluster",
    "CartographClusterResponse",
    "CategoricalPromptFilterParam",
    "CategoryFilterOperator",
    "CBOClusterRequest",
    "CBOClusterResponse",
    "CBORunCluster",
    "ChainPollTemplate",
    "ChainRow",
    "ChainRowInputsType0",
    "ChainRowParams",
    "ChainStep",
    "ChainStepInputType3",
    "ChainStepInputType7Item",
    "ChainStepInputType8Item",
    "ChainStepMetadata",
    "ChainStepOutputType3",
    "ChainStepOutputType7Item",
    "ChainStepOutputType8Item",
    "Changes",
    "ChunkAttributionUtilizationScorer",
    "ChunkAttributionUtilizationScorerType",
    "ChunkAttributionUtilizationTemplate",
    "Circle",
    "CollaboratorRole",
    "CollaboratorRoleInfo",
    "CollaboratorUpdate",
    "ColumnCategory",
    "CommunityResponse",
    "CompareRunsResponse",
    "CompletenessScorer",
    "CompletenessScorerType",
    "CompletenessTemplate",
    "CompositeProjectSettings",
    "CompositeProjectSettingsMetricWeightsConfigurationType0",
    "ContentRequest",
    "ContextAdherenceScorer",
    "ContextAdherenceScorerType",
    "ContextRelevanceScorer",
    "CorrectnessScorer",
    "CreateAlertConfigurationRequest",
    "CreateApiKeyRequest",
    "CreateApiKeyResponse",
    "CreateComputeScoreRequest",
    "CreateGeneratedScorerRequest",
    "CreateJobRequest",
    "CreateJobResponse",
    "CreateLLMScorerVersionRequest",
    "CreateMetricCritiqueRequest",
    "CreateMetricCritiquesRequest",
    "CreatePromptTemplateWithVersionRequestBody",
    "CreateRunResponse",
    "CreateScorerRequest",
    "CreateSignupLinkResponse",
    "CreateUpdateRegisteredScorerResponse",
    "CreateUserResponse",
    "CurrentUserDB",
    "CustomizedAgenticWorkflowSuccessGPTScorer",
    "CustomizedAgenticWorkflowSuccessGPTScorerAggregatesType0",
    "CustomizedAgenticWorkflowSuccessGPTScorerExtraType0",
    "CustomizedChunkAttributionUtilizationGPTScorer",
    "CustomizedChunkAttributionUtilizationGPTScorerAggregatesType0",
    "CustomizedChunkAttributionUtilizationGPTScorerExtraType0",
    "CustomizedCompletenessGPTScorer",
    "CustomizedCompletenessGPTScorerAggregatesType0",
    "CustomizedCompletenessGPTScorerExtraType0",
    "CustomizedFactualityGPTScorer",
    "CustomizedFactualityGPTScorerAggregatesType0",
    "CustomizedFactualityGPTScorerExtraType0",
    "CustomizedGroundednessGPTScorer",
    "CustomizedGroundednessGPTScorerAggregatesType0",
    "CustomizedGroundednessGPTScorerExtraType0",
    "CustomizedGroundTruthAdherenceGPTScorer",
    "CustomizedGroundTruthAdherenceGPTScorerAggregatesType0",
    "CustomizedGroundTruthAdherenceGPTScorerExtraType0",
    "CustomizedInstructionAdherenceGPTScorer",
    "CustomizedInstructionAdherenceGPTScorerAggregatesType0",
    "CustomizedInstructionAdherenceGPTScorerExtraType0",
    "CustomizedScorer",
    "CustomizedScorerName",
    "CustomizedToolErrorRateGPTScorer",
    "CustomizedToolErrorRateGPTScorerAggregatesType0",
    "CustomizedToolErrorRateGPTScorerExtraType0",
    "CustomizedToolSelectionQualityGPTScorer",
    "CustomizedToolSelectionQualityGPTScorerAggregatesType0",
    "CustomizedToolSelectionQualityGPTScorerExtraType0",
    "DatabricksEditExportRequest",
    "DatabricksEditExportRequestColMappingType0",
    "DatabricksEditExportResponse",
    "DatabricksEditExportResponseColMappingType0",
    "DatabricksExportRequest",
    "DatabricksExportRequestColMappingType0",
    "DatabricksExportResponse",
    "DatabricksExportResponseColMappingType0",
    "DatabricksIntegration",
    "DatabricksIntegrationCreate",
    "DatabricksIntegrationExtraType0",
    "DatabricksObserveExportRequest",
    "DatabricksUnityCatalogEditExportRequest",
    "DatabricksUnityCatalogEditExportRequestColMappingType0",
    "DatabricksUnityCatalogExportEditsResponse",
    "DatabricksUnityCatalogExportEditsResponseColMappingType0",
    "DatabricksUnityCatalogExportResponse",
    "DatabricksUnityCatalogExportResponseColMappingType0",
    "DataRow",
    "DataRowMetaType0",
    "DataRows",
    "DataRowSystemPromptsType0",
    "DatasetAction",
    "DatasetAddColumn",
    "DatasetAppendRow",
    "DatasetAppendRowValues",
    "DatasetContent",
    "DatasetContentFilter",
    "DatasetContentFilterOperator",
    "DatasetContentSortClause",
    "DatasetCreatedAtSort",
    "DatasetDB",
    "DatasetDeleteColumn",
    "DatasetDeleteRow",
    "DatasetFormat",
    "DatasetLastEditedByUserAtSort",
    "DatasetNameFilter",
    "DatasetNameFilterOperator",
    "DatasetNameSort",
    "DatasetProjectLastUsedAtSort",
    "DatasetProjectsSort",
    "DatasetRenameColumn",
    "DatasetRow",
    "DatasetRowsSort",
    "DatasetType",
    "DatasetUpdatedAtSort",
    "DatasetUpdateRow",
    "DatasetUpdateRowValues",
    "DatasetUsedInProjectFilter",
    "DatasetVersionDB",
    "DatasetVersionIndexSort",
    "DataTypeOptions",
    "DeletePromptResponse",
    "DeleteRunResponse",
    "DeleteRunsRequest",
    "DeleteRunsResponse",
    "DeleteUserResponse",
    "Distribution",
    "DistributionRequest",
    "Document",
    "DocumentMetadata",
    "EditAction",
    "EditContent",
    "EditContentEditSpansType0",
    "EditCreateRequest",
    "EditCreateRequestEditSpansType0",
    "EditCreateResponse",
    "EditCreateResponseEditSpansType0",
    "EditDeleteResponse",
    "EditExportDB",
    "EditExportRequest",
    "EditExportRequestColMappingType0",
    "EditGetResponse",
    "EditGetResponseEditSpansType0",
    "EditOverride",
    "EditOverrideEditSpansType0",
    "EditReviewDB",
    "EditRowData",
    "EditRowDataMetaType0",
    "EditSpan",
    "EditSummary",
    "EmailVerificationRequest",
    "EmbeddingData",
    "EmbeddingDataMetaType0",
    "EmbeddingPointRequest",
    "EmbeddingPointResponse",
    "EmbeddingRequest",
    "ErrorDistribution",
    "EvaluateAlertDB",
    "EvaluateAlertDBExtraType0",
    "EvaluateProjectSettings",
    "EvaluateProjectSettingsMetricWeightsConfigurationType0",
    "EvaluateRunRequest",
    "EvaluateRunResponse",
    "EvaluateRunResultsRequest",
    "ExecutionStatus",
    "ExperimentCreateRequest",
    "ExperimentResponse",
    "ExperimentUpdateRequest",
    "ExportRequest",
    "ExportRequestColMappingType0",
    "ExtraAlertFilters",
    "FactualityTemplate",
    "FeatureColumnsResponse",
    "FeedbackAggregate",
    "FeedbackRatingCreate",
    "FeedbackRatingDB",
    "FeedbackRatingOperationType",
    "FeedbackTemplateCreate",
    "FeedbackTemplateDB",
    "FeedbackTemplateUpdate",
    "FewShotExample",
    "FieldType",
    "FileType",
    "FilterOptionsResponse",
    "FilterOptionsResponseFilterOptions",
    "FilterParams",
    "FilterPercentageRequest",
    "FilterPercentageResponse",
    "FiltersRequestBody",
    "GenAIProjectSettings",
    "GeneratedScorer",
    "GeneratedScorerAction",
    "GeneratedScorerConfig",
    "GeneratedScorerConfiguration",
    "GeneratedScorerResponse",
    "GeneratedScorerTaskResultResponse",
    "GeneratedScorerTaskResultStatus",
    "GeneratedScorerTaskResultType",
    "GeneratedScorerValidationRequest",
    "GeneratedScorerValidationResponse",
    "GeneratedScorerValidationResult",
    "GenerationRequest",
    "GenerationResponse",
    "GenericAction",
    "GenericPermission",
    "GetApiKeyResponse",
    "GetIntegrationStatusIntegrationsNameStatusGetResponseGetIntegrationStatusIntegrationsNameStatusGet",
    "GetMetricsSchemaEndpointProjectsProjectIdObserveColumnSchemaGetResponseGetMetricsSchemaEndpointProjectsProjectIdObserveColumnSchemaGet",
    "GetMultiRunSamplesForRowIdsProjectsProjectIdRunsPromptsRowsColumnarPostResponseGetMultiRunSamplesForRowIdsProjectsProjectIdRunsPromptsRowsColumnarPost",
    "GetMultiRunSamplesForRowIdsProjectsProjectIdRunsPromptsRowsColumnarPostRowIds",
    "GetObserveWorkflowsRequest",
    "GetPresignedUrlResponse",
    "GetProjectsPaginatedResponse",
    "GetPromptRowsColumnarResponse",
    "GetPromptRowsResponse",
    "GetPromptRun",
    "GetPromptRunColumnsResponse",
    "GetPromptRunMetrics",
    "GetPromptRunsResponse",
    "GetSplitsResponse",
    "GetTokenForTrainingJobTrainingTrainingJobIdTokenPostRequestBody",
    "GetTokenResponse",
    "GetUsagePlansUsagePlansGetResponseGetUsagePlansUsagePlansGet",
    "GetUserLatestRunsDB",
    "GetUserResponse",
    "GetUsersResponse",
    "GroundednessTemplate",
    "GroundTruthAdherenceScorer",
    "GroundTruthAdherenceTemplate",
    "GroupAction",
    "GroupByMetrics",
    "GroupCollaborator",
    "GroupCollaboratorCreate",
    "GroupCreate",
    "GroupDB",
    "GroupLabel",
    "GroupMemberAction",
    "GroupMemberCreate",
    "GroupMemberDB",
    "GroupMemberUpdate",
    "GroupRole",
    "GroupRoleInfo",
    "GroupUpdate",
    "GroupVisibility",
    "HallucinationSegment",
    "HasEmbeddingsResponse",
    "HealthcheckResponse",
    "HTTPValidationError",
    "IndexSelector",
    "InferenceModelMetrics",
    "InferenceNamesResponse",
    "InferenceResults",
    "InferenceRunResults",
    "InputMap",
    "InputPIIScorer",
    "InputSexistScorer",
    "InputToneScorer",
    "InputToxicityScorer",
    "InsightChartRequest",
    "InsightChartResponse",
    "InsightType",
    "InstructionAdherenceScorer",
    "InstructionAdherenceTemplate",
    "IntegrationDB",
    "IntegrationName",
    "InviteUsersRequest",
    "InvokeResponse",
    "InvokeResponseHeadersType0",
    "InvokeResponseMetadataType0",
    "InvokeResponseMetricResults",
    "JobDB",
    "JobDBRequestData",
    "JobInfo",
    "JobStatus",
    "LabelCoOccurences",
    "LabelResponse",
    "LabelStudioExportRequest",
    "LabelStudioIntegration",
    "LabelStudioIntegrationCreate",
    "LabelStudioIntegrationExtraType0",
    "LabelStudioProject",
    "LassoSelection",
    "LikeDislikeAggregate",
    "LikeDislikeConstraints",
    "LikeDislikeRating",
    "ListAlertConfigurationsResponse",
    "ListApiKeyResponse",
    "ListDatasetParams",
    "ListDatasetResponse",
    "ListDatasetVersionParams",
    "ListDatasetVersionResponse",
    "ListGeneratedScorersResponse",
    "ListGroupCollaboratorsResponse",
    "ListGroupMembersResponse",
    "ListGroupsResponse",
    "ListMetaRequest",
    "ListMetaResponse",
    "ListOrganizationsResponse",
    "ListPromptDatasetResponse",
    "ListRegisteredScorersResponse",
    "ListScorersRequest",
    "ListScorersResponse",
    "ListUserCollaboratorsResponse",
    "LLMExportFormat",
    "LLMIntegration",
    "LlmSpan",
    "LlmSpanInputType3",
    "LlmSpanInputType7Item",
    "LlmSpanInputType8Item",
    "LlmSpanMetadata",
    "LlmSpanOutputType3",
    "LlmSpanOutputType7Item",
    "LlmSpanOutputType8Item",
    "LlmSpanToolsType0Item",
    "LlmSpanWithMetrics",
    "LlmSpanWithMetricsInputType3",
    "LlmSpanWithMetricsInputType7Item",
    "LlmSpanWithMetricsInputType8Item",
    "LlmSpanWithMetricsMetadata",
    "LlmSpanWithMetricsMetrics",
    "LlmSpanWithMetricsOutputType3",
    "LlmSpanWithMetricsOutputType7Item",
    "LlmSpanWithMetricsOutputType8Item",
    "LlmSpanWithMetricsToolsType0Item",
    "LlmStep",
    "LlmStepInputType1",
    "LlmStepInputType4Item",
    "LlmStepMetadata",
    "LlmStepOutputType1",
    "LlmStepOutputType4Item",
    "LlmStepToolsType0Item",
    "LogDataAvailableColumnsRequest",
    "LogDataAvailableColumnsResponse",
    "LogDataColumnInfo",
    "LogDataIDColumnFilter",
    "LogDataLoggingMethod",
    "LogDataNodeTypeFilter",
    "LogDataNodeTypeFilterOperator",
    "LogDataQueryRequest",
    "LogDataQueryResponse",
    "LogStreamCreateRequest",
    "LogStreamResponse",
    "LogStreamUpdateRequest",
    "MAPResponse",
    "Message",
    "MessageRole",
    "MetadataFilter",
    "MetadataFilterOperator",
    "MetaFilter",
    "MetaInfo",
    "Method",
    "MetricComputation",
    "MetricComputationStatus",
    "MetricComputationValueType4",
    "MetricComputing",
    "MetricCritique",
    "MetricCritiqueColumn",
    "MetricCritiqueColumnar",
    "MetricCritiqueColumns",
    "MetricCritiqueContent",
    "MetricCritiqueJobConfiguration",
    "MetricDescriptions",
    "MetricError",
    "MetricFailed",
    "MetricInputs",
    "MetricInsight",
    "MetricInsightCategories",
    "MetricNotApplicable",
    "MetricNotComputed",
    "MetricPending",
    "Metrics",
    "MetricsRequest",
    "MetricsResponse",
    "MetricSuccess",
    "MetricThreshold",
    "MetricWeight",
    "MistralIntegration",
    "MistralIntegrationCreate",
    "MistralIntegrationExtraType0",
    "Model",
    "ModelCostBy",
    "ModelInfo",
    "ModelKind",
    "ModelMetrics",
    "ModelType",
    "ModelUploadStatus",
    "MultiLabelCoOccurrence",
    "MultiLabelTaskMetrics",
    "NodeNameFilter",
    "NodeNameFilterOperator",
    "NodeType",
    "NoiseType",
    "ObserveProjectSettings",
    "OpenAIFunction",
    "OpenAIIntegration",
    "OpenAIIntegrationCreate",
    "OpenAIIntegrationExtraType0",
    "OpenAIToolChoice",
    "Operator",
    "OrganizationAction",
    "OrganizationCreate",
    "OrganizationCreatedAtSort",
    "OrganizationDB",
    "OrganizationIsMemberFilter",
    "OrganizationNameFilter",
    "OrganizationNameFilterOperator",
    "OrganizationNameSort",
    "OutputMap",
    "OutputPIIScorer",
    "OutputSexistScorer",
    "OutputToneScorer",
    "OutputToxicityScorer",
    "OverrideAction",
    "PassthroughAction",
    "PasswordResetEmailResponse",
    "PasswordResetResponse",
    "Payload",
    "Permission",
    "PolygonData",
    "PolygonSize",
    "ProjectAction",
    "ProjectBookmarkFilter",
    "ProjectBookmarkSort",
    "ProjectCollectionParams",
    "ProjectCreate",
    "ProjectCreatedAtFilter",
    "ProjectCreatedAtFilterOperator",
    "ProjectCreatedAtSort",
    "ProjectCreateResponse",
    "ProjectCreatorFilter",
    "ProjectDB",
    "ProjectDBThin",
    "ProjectDeleteResponse",
    "ProjectIDFilter",
    "ProjectIntegration",
    "ProjectIntegrationsResponse",
    "ProjectIntegrationsResponseIntegrations",
    "ProjectNameFilter",
    "ProjectNameFilterOperator",
    "ProjectNameSort",
    "ProjectRunsFilter",
    "ProjectRunsFilterOperator",
    "ProjectRunsSort",
    "ProjectRunSummary",
    "ProjectSettingsDB",
    "ProjectSettingsDBMetricWeightsConfigurationType0",
    "ProjectType",
    "ProjectTypeFilter",
    "ProjectTypeFilterOperator",
    "ProjectTypeSort",
    "ProjectUpdate",
    "ProjectUpdatedAtFilter",
    "ProjectUpdatedAtFilterOperator",
    "ProjectUpdatedAtSort",
    "ProjectUpdateResponse",
    "PromptChainIngestBatchRequest",
    "PromptChainIngestBatchResponse",
    "PromptChainIngestRequest",
    "PromptChainIngestResponse",
    "PromptDatasetDB",
    "PromptFilterParams",
    "PromptGroupResponse",
    "PromptInjectionScorer",
    "PromptOptimizationConfiguration",
    "PromptPerplexityScorer",
    "PromptRow",
    "PromptRowColumn",
    "PromptRowInputs",
    "PromptRowNodeOutputType2",
    "PromptRunColumn",
    "PromptRunSettings",
    "PromptRunSettingsResponseFormatType0",
    "PromptRunSettingsToolsType0Item",
    "PromptSampleIDs",
    "PromptSampleIDsSampleIndices",
    "PutPromptScoreRequest",
    "PutPromptScoreRequestAggregatesType0",
    "PutPromptScoreResponse",
    "QueryDatasetParams",
    "QueryFilterV1",
    "QueryOrganizationParams",
    "RangePromptFilterParam",
    "RecomputeSettingsObserve",
    "RecomputeSettingsObserveBase",
    "RecomputeSettingsProject",
    "RecomputeSettingsRuns",
    "RegisteredScorer",
    "RegisteredScorerAction",
    "RegisteredScorerConfig",
    "RemoteEditExportRequest",
    "RemoteEditExportRequestColMappingType0",
    "RemoteEditExportResponse",
    "RemoteEditExportResponseColMappingType0",
    "RemoteExportRequest",
    "RemoteExportRequestColMappingType0",
    "RemoteExportResponse",
    "RemoteExportResponseColMappingType0",
    "Request",
    "RequestHeadersType0",
    "RequestMetadataType0",
    "ResourceKind",
    "Response",
    "RetrieverSpan",
    "RetrieverSpanInputType3",
    "RetrieverSpanInputType7Item",
    "RetrieverSpanInputType8Item",
    "RetrieverSpanMetadata",
    "RetrieverSpanOutputType3",
    "RetrieverSpanOutputType7Item",
    "RetrieverSpanOutputType8Item",
    "RetrieverSpanWithMetrics",
    "RetrieverSpanWithMetricsInputType3",
    "RetrieverSpanWithMetricsInputType7Item",
    "RetrieverSpanWithMetricsInputType8Item",
    "RetrieverSpanWithMetricsMetadata",
    "RetrieverSpanWithMetricsMetrics",
    "RetrieverSpanWithMetricsOutputType3",
    "RetrieverSpanWithMetricsOutputType7Item",
    "RetrieverSpanWithMetricsOutputType8Item",
    "RetrieverStep",
    "RetrieverStepMetadata",
    "RollbackRequest",
    "RougeScorer",
    "Rule",
    "RuleOperator",
    "RuleResult",
    "Ruleset",
    "RulesetResult",
    "RulesetsMixin",
    "RunCreate",
    "RunDB",
    "RunDBThin",
    "RunDBThinWithProjectName",
    "RunLinkResponse",
    "RunMetricCreateRequest",
    "RunMetricCreateRequestExtraType1",
    "RunMetricDB",
    "RunMetricDBExtraType1",
    "RunParamsMap",
    "RunResults",
    "RunResultsTopErroneousWordsType0",
    "RunScorerSettingsRequest",
    "RunTagCreateRequest",
    "RunTagDB",
    "RunUpdateRequest",
    "ScoreAggregate",
    "ScoreConstraints",
    "ScoreRating",
    "ScorerConfig",
    "ScorerCreatedAtFilter",
    "ScorerCreatedAtFilterOperator",
    "ScorerCreatorFilter",
    "ScorerDefaults",
    "ScorerName",
    "ScorerNameFilter",
    "ScorerNameFilterOperator",
    "ScorerResponse",
    "ScorersConfig",
    "ScorersConfiguration",
    "ScorerTagsFilter",
    "ScorerTagsFilterOperator",
    "ScorerType",
    "ScorerTypeFilter",
    "ScorerTypeFilterOperator",
    "ScorerTypes",
    "ScorerUpdatedAtFilter",
    "ScorerUpdatedAtFilterOperator",
    "ScorerVersionResponse",
    "ScorerVersionsResponse",
    "Segment",
    "SegmentationMetricsResponse",
    "SemSegErrorType",
    "Seq2SeqMetricsResponse",
    "Seq2SeqSegment",
    "SimilarToResponse",
    "SliceCreate",
    "SliceCreateResponse",
    "SliceDB",
    "SliceDeleteResponse",
    "SliceMetrics",
    "SliceUpdate",
    "SliceUpdateResponse",
    "SocialLoginRequest",
    "SocialProvider",
    "SortClause",
    "SortDirection",
    "Span",
    "Split",
    "SplitRunResults",
    "StageDB",
    "StageMetadata",
    "StageType",
    "StageWithRulesets",
    "StandardColumnSort",
    "StarAggregate",
    "StarAggregateCounts",
    "StarConstraints",
    "StarRating",
    "StartTrainingJobProjectsProjectIdTrainingModeStartPostRequestBody",
    "StepMetric",
    "StepWithChildren",
    "StepWithChildrenInputType3",
    "StepWithChildrenInputType7Item",
    "StepWithChildrenInputType8Item",
    "StepWithChildrenMetadata",
    "StepWithChildrenOutputType3",
    "StepWithChildrenOutputType7Item",
    "StepWithChildrenOutputType8Item",
    "StepWithChildSpans",
    "StepWithChildSpansInputType3",
    "StepWithChildSpansInputType7Item",
    "StepWithChildSpansInputType8Item",
    "StepWithChildSpansMetadata",
    "StepWithChildSpansOutputType3",
    "StepWithChildSpansOutputType7Item",
    "StepWithChildSpansOutputType8Item",
    "SubscriptionConfig",
    "SummaryIDRequest",
    "SummaryIDResponse",
    "SummaryRequest",
    "TaggingSchema",
    "TagsAggregate",
    "TagsAggregateCounts",
    "TagsConstraints",
    "TagsRating",
    "TargetLabels",
    "TaskResponse",
    "TaskType",
    "TextConstraints",
    "TextRating",
    "ThresholdRequest",
    "ThresholdResponse",
    "Token",
    "ToolErrorRateScorer",
    "ToolErrorRateTemplate",
    "ToolSelectionQualityScorer",
    "ToolSelectionQualityTemplate",
    "ToolSpan",
    "ToolSpanInputType3",
    "ToolSpanInputType7Item",
    "ToolSpanInputType8Item",
    "ToolSpanMetadata",
    "ToolSpanOutputType3",
    "ToolSpanOutputType7Item",
    "ToolSpanOutputType8Item",
    "ToolSpanWithMetrics",
    "ToolSpanWithMetricsInputType3",
    "ToolSpanWithMetricsInputType7Item",
    "ToolSpanWithMetricsInputType8Item",
    "ToolSpanWithMetricsMetadata",
    "ToolSpanWithMetricsMetrics",
    "ToolSpanWithMetricsOutputType3",
    "ToolSpanWithMetricsOutputType7Item",
    "ToolSpanWithMetricsOutputType8Item",
    "ToolStep",
    "ToolStepInputType3",
    "ToolStepInputType7Item",
    "ToolStepInputType8Item",
    "ToolStepMetadata",
    "ToolStepOutputType3",
    "ToolStepOutputType7Item",
    "ToolStepOutputType8Item",
    "TopInsightsRequest",
    "TopInsightsResponse",
    "TopInsightsResponseTopCorrelationPairs",
    "TopInsightsResponseTopErroneousWords",
    "TopInsightsResponseTopMisclassifiedPairsItem",
    "TopKToken",
    "Trace",
    "TraceInputType3",
    "TraceInputType7Item",
    "TraceInputType8Item",
    "TraceMetadata",
    "TraceOutputType3",
    "TraceOutputType7Item",
    "TraceOutputType8Item",
    "TracesIngestRequest",
    "TracesIngestResponse",
    "TraceTraceMetadata",
    "TraceWithMetrics",
    "TraceWithMetricsInputType3",
    "TraceWithMetricsInputType7Item",
    "TraceWithMetricsInputType8Item",
    "TraceWithMetricsMetadata",
    "TraceWithMetricsMetrics",
    "TraceWithMetricsOutputType3",
    "TraceWithMetricsOutputType7Item",
    "TraceWithMetricsOutputType8Item",
    "TrainingModelResponse",
    "TrainingModelResponseParameters",
    "TrainJobAuthTokenResponse",
    "TrainJobStatusResponse",
    "TrainResponse",
    "TransactionLoggingMethod",
    "TransactionMetricsResponse",
    "TransactionMetricsResponseBucketedMetrics",
    "TransactionRecordBatch",
    "TransactionRecordDBOutputLogprobsType0",
    "TransactionRecordDBUserMetadataType0",
    "TransactionRecordIngest",
    "TransactionRecordIngestOutputLogprobsType0",
    "TransactionRecordIngestUserMetadataType0",
    "TransactionRecordStatus",
    "TransactionRowsRequestBody",
    "TransferUserResponse",
    "UncertaintyScorer",
    "UpdateAlertConfigurationRequest",
    "UpdateDatasetContentRequest",
    "UpdateDatasetRequest",
    "UpdateDatasetVersionRequest",
    "UpdateGeneratedScorerRequest",
    "UpdateRunResponse",
    "UpdateScorerRequest",
    "UpdateUserResponse",
    "UploadModel",
    "UploadModelParameters",
    "UploadModelResponse",
    "UsagePlan",
    "UsagePlanName",
    "UserAction",
    "UserCollaborator",
    "UserCollaboratorCreate",
    "UserCreate",
    "UserDB",
    "UserInfo",
    "UserMetadataFilter",
    "UserMetadataFilterOperator",
    "UserPasswordResetRequest",
    "UserPasswordResetResponse",
    "UserRole",
    "UserRoleInfo",
    "UserUpdate",
    "ValidationError",
    "ValidationRequest",
    "ValidationResponse",
    "ValuePromptFilterParam",
    "VertexAIIntegration",
    "VertexAIIntegrationCreate",
    "VertexAIIntegrationExtraType0",
    "Webhook",
    "WebhookStatus",
    "WeeklyChangelog",
    "WeeklyChangelogChanges",
    "WorkflowCountResponse",
    "WorkflowsIngestRequest",
    "WorkflowsIngestResponse",
    "WorkflowSpan",
    "WorkflowSpanInputType3",
    "WorkflowSpanInputType7Item",
    "WorkflowSpanInputType8Item",
    "WorkflowSpanMetadata",
    "WorkflowSpanOutputType3",
    "WorkflowSpanOutputType7Item",
    "WorkflowSpanOutputType8Item",
    "WorkflowSpanWithMetrics",
    "WorkflowSpanWithMetricsInputType3",
    "WorkflowSpanWithMetricsInputType7Item",
    "WorkflowSpanWithMetricsInputType8Item",
    "WorkflowSpanWithMetricsMetadata",
    "WorkflowSpanWithMetricsMetrics",
    "WorkflowSpanWithMetricsOutputType3",
    "WorkflowSpanWithMetricsOutputType7Item",
    "WorkflowSpanWithMetricsOutputType8Item",
    "WorkflowsReadResponse",
    "WorkflowStep",
    "WorkflowStepInputType3",
    "WorkflowStepInputType7Item",
    "WorkflowStepInputType8Item",
    "WorkflowStepMetadata",
    "WorkflowStepOutputType3",
    "WorkflowStepOutputType7Item",
    "WorkflowStepOutputType8Item",
    "WriterIntegration",
    "WriterIntegrationCreate",
    "WriterIntegrationExtraType0",
    "XRayCardDB",
    "XRayCardDBMessageFields",
    "XRayClass",
)



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.base_galileo_step_input_type_3 import BaseGalileoStepInputType3
    from ..models.base_galileo_step_input_type_7_item import BaseGalileoStepInputType7Item
    from ..models.base_galileo_step_input_type_8_item import BaseGalileoStepInputType8Item
    from ..models.base_galileo_step_metadata import BaseGalileoStepMetadata
    from ..models.base_galileo_step_output_type_3 import BaseGalileoStepOutputType3
    from ..models.base_galileo_step_output_type_7_item import BaseGalileoStepOutputType7Item
    from ..models.base_galileo_step_output_type_8_item import BaseGalileoStepOutputType8Item
    from ..models.document import Document
    from ..models.message import Message
    from ..models.step_metric import StepMetric


T = TypeVar("T", bound="BaseGalileoStep")


@_attrs_define
class BaseGalileoStep:
    """
    Attributes:
        input_ (Union['BaseGalileoStepInputType3', 'Document', 'Message', list['BaseGalileoStepInputType7Item'],
            list['BaseGalileoStepInputType8Item'], list['Document'], list['Message'], list[str], str]): Input to the step.
        created_at_ns (Union[Unset, int]): Timestamp of the step's creation, as nanoseconds since epoch.
        duration_ns (Union[Unset, int]): Duration of the step in nanoseconds. Default: 0.
        ground_truth (Union[None, Unset, str]): Ground truth expected output for the step.
        metadata (Union[Unset, BaseGalileoStepMetadata]): Metadata associated with this step.
        metrics (Union[None, Unset, list['StepMetric']]):
        name (Union[Unset, str]): Name of the step. Default: ''.
        output (Union['BaseGalileoStepOutputType3', 'Document', 'Message', Unset,
            list['BaseGalileoStepOutputType7Item'], list['BaseGalileoStepOutputType8Item'], list['Document'],
            list['Message'], list[str], str]): Output of the step. Default: ''.
        root_workflow_id (Union[None, Unset, str]):
        status_code (Union[None, Unset, int]): Status code of the step. Used for logging failed/errored steps.
        step_id (Union[None, Unset, str]):
        steps (Union[None, Unset, list['BaseGalileoStep']]):
        type_ (Union[Unset, Any]): Type of the step. By default, it is set to workflow. Default: 'workflow'.
        workflow_id (Union[None, Unset, str]):
    """

    input_: Union[
        "BaseGalileoStepInputType3",
        "Document",
        "Message",
        list["BaseGalileoStepInputType7Item"],
        list["BaseGalileoStepInputType8Item"],
        list["Document"],
        list["Message"],
        list[str],
        str,
    ]
    created_at_ns: Union[Unset, int] = UNSET
    duration_ns: Union[Unset, int] = 0
    ground_truth: Union[None, Unset, str] = UNSET
    metadata: Union[Unset, "BaseGalileoStepMetadata"] = UNSET
    metrics: Union[None, Unset, list["StepMetric"]] = UNSET
    name: Union[Unset, str] = ""
    output: Union[
        "BaseGalileoStepOutputType3",
        "Document",
        "Message",
        Unset,
        list["BaseGalileoStepOutputType7Item"],
        list["BaseGalileoStepOutputType8Item"],
        list["Document"],
        list["Message"],
        list[str],
        str,
    ] = ""
    root_workflow_id: Union[None, Unset, str] = UNSET
    status_code: Union[None, Unset, int] = UNSET
    step_id: Union[None, Unset, str] = UNSET
    steps: Union[None, Unset, list["BaseGalileoStep"]] = UNSET
    type_: Union[Unset, Any] = "workflow"
    workflow_id: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.base_galileo_step_input_type_3 import BaseGalileoStepInputType3
        from ..models.base_galileo_step_output_type_3 import BaseGalileoStepOutputType3
        from ..models.document import Document
        from ..models.message import Message

        input_: Union[dict[str, Any], list[dict[str, Any]], list[str], str]
        if isinstance(self.input_, Document):
            input_ = self.input_.to_dict()
        elif isinstance(self.input_, Message):
            input_ = self.input_.to_dict()
        elif isinstance(self.input_, BaseGalileoStepInputType3):
            input_ = self.input_.to_dict()
        elif isinstance(self.input_, list):
            input_ = self.input_

        elif isinstance(self.input_, list):
            input_ = []
            for input_type_5_item_data in self.input_:
                input_type_5_item = input_type_5_item_data.to_dict()
                input_.append(input_type_5_item)

        elif isinstance(self.input_, list):
            input_ = []
            for input_type_6_item_data in self.input_:
                input_type_6_item = input_type_6_item_data.to_dict()
                input_.append(input_type_6_item)

        elif isinstance(self.input_, list):
            input_ = []
            for input_type_7_item_data in self.input_:
                input_type_7_item = input_type_7_item_data.to_dict()
                input_.append(input_type_7_item)

        elif isinstance(self.input_, list):
            input_ = []
            for input_type_8_item_data in self.input_:
                input_type_8_item = input_type_8_item_data.to_dict()
                input_.append(input_type_8_item)

        else:
            input_ = self.input_

        created_at_ns = self.created_at_ns

        duration_ns = self.duration_ns

        ground_truth: Union[None, Unset, str]
        if isinstance(self.ground_truth, Unset):
            ground_truth = UNSET
        else:
            ground_truth = self.ground_truth

        metadata: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        metrics: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.metrics, Unset):
            metrics = UNSET
        elif isinstance(self.metrics, list):
            metrics = []
            for metrics_type_0_item_data in self.metrics:
                metrics_type_0_item = metrics_type_0_item_data.to_dict()
                metrics.append(metrics_type_0_item)

        else:
            metrics = self.metrics

        name = self.name

        output: Union[Unset, dict[str, Any], list[dict[str, Any]], list[str], str]
        if isinstance(self.output, Unset):
            output = UNSET
        elif isinstance(self.output, Document):
            output = self.output.to_dict()
        elif isinstance(self.output, Message):
            output = self.output.to_dict()
        elif isinstance(self.output, BaseGalileoStepOutputType3):
            output = self.output.to_dict()
        elif isinstance(self.output, list):
            output = self.output

        elif isinstance(self.output, list):
            output = []
            for output_type_5_item_data in self.output:
                output_type_5_item = output_type_5_item_data.to_dict()
                output.append(output_type_5_item)

        elif isinstance(self.output, list):
            output = []
            for output_type_6_item_data in self.output:
                output_type_6_item = output_type_6_item_data.to_dict()
                output.append(output_type_6_item)

        elif isinstance(self.output, list):
            output = []
            for output_type_7_item_data in self.output:
                output_type_7_item = output_type_7_item_data.to_dict()
                output.append(output_type_7_item)

        elif isinstance(self.output, list):
            output = []
            for output_type_8_item_data in self.output:
                output_type_8_item = output_type_8_item_data.to_dict()
                output.append(output_type_8_item)

        else:
            output = self.output

        root_workflow_id: Union[None, Unset, str]
        if isinstance(self.root_workflow_id, Unset):
            root_workflow_id = UNSET
        else:
            root_workflow_id = self.root_workflow_id

        status_code: Union[None, Unset, int]
        if isinstance(self.status_code, Unset):
            status_code = UNSET
        else:
            status_code = self.status_code

        step_id: Union[None, Unset, str]
        if isinstance(self.step_id, Unset):
            step_id = UNSET
        else:
            step_id = self.step_id

        steps: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.steps, Unset):
            steps = UNSET
        elif isinstance(self.steps, list):
            steps = []
            for steps_type_0_item_data in self.steps:
                steps_type_0_item = steps_type_0_item_data.to_dict()
                steps.append(steps_type_0_item)

        else:
            steps = self.steps

        type_ = self.type_

        workflow_id: Union[None, Unset, str]
        if isinstance(self.workflow_id, Unset):
            workflow_id = UNSET
        else:
            workflow_id = self.workflow_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"input": input_})
        if created_at_ns is not UNSET:
            field_dict["created_at_ns"] = created_at_ns
        if duration_ns is not UNSET:
            field_dict["duration_ns"] = duration_ns
        if ground_truth is not UNSET:
            field_dict["ground_truth"] = ground_truth
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if metrics is not UNSET:
            field_dict["metrics"] = metrics
        if name is not UNSET:
            field_dict["name"] = name
        if output is not UNSET:
            field_dict["output"] = output
        if root_workflow_id is not UNSET:
            field_dict["root_workflow_id"] = root_workflow_id
        if status_code is not UNSET:
            field_dict["status_code"] = status_code
        if step_id is not UNSET:
            field_dict["step_id"] = step_id
        if steps is not UNSET:
            field_dict["steps"] = steps
        if type_ is not UNSET:
            field_dict["type"] = type_
        if workflow_id is not UNSET:
            field_dict["workflow_id"] = workflow_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.base_galileo_step_input_type_3 import BaseGalileoStepInputType3
        from ..models.base_galileo_step_input_type_7_item import BaseGalileoStepInputType7Item
        from ..models.base_galileo_step_input_type_8_item import BaseGalileoStepInputType8Item
        from ..models.base_galileo_step_metadata import BaseGalileoStepMetadata
        from ..models.base_galileo_step_output_type_3 import BaseGalileoStepOutputType3
        from ..models.base_galileo_step_output_type_7_item import BaseGalileoStepOutputType7Item
        from ..models.base_galileo_step_output_type_8_item import BaseGalileoStepOutputType8Item
        from ..models.document import Document
        from ..models.message import Message
        from ..models.step_metric import StepMetric

        d = src_dict.copy()

        def _parse_input_(
            data: object,
        ) -> Union[
            "BaseGalileoStepInputType3",
            "Document",
            "Message",
            list["BaseGalileoStepInputType7Item"],
            list["BaseGalileoStepInputType8Item"],
            list["Document"],
            list["Message"],
            list[str],
            str,
        ]:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                input_type_1 = Document.from_dict(data)

                return input_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                input_type_2 = Message.from_dict(data)

                return input_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                input_type_3 = BaseGalileoStepInputType3.from_dict(data)

                return input_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                input_type_4 = cast(list[str], data)

                return input_type_4
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                input_type_5 = []
                _input_type_5 = data
                for input_type_5_item_data in _input_type_5:
                    input_type_5_item = Document.from_dict(input_type_5_item_data)

                    input_type_5.append(input_type_5_item)

                return input_type_5
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                input_type_6 = []
                _input_type_6 = data
                for input_type_6_item_data in _input_type_6:
                    input_type_6_item = Message.from_dict(input_type_6_item_data)

                    input_type_6.append(input_type_6_item)

                return input_type_6
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                input_type_7 = []
                _input_type_7 = data
                for input_type_7_item_data in _input_type_7:
                    input_type_7_item = BaseGalileoStepInputType7Item.from_dict(input_type_7_item_data)

                    input_type_7.append(input_type_7_item)

                return input_type_7
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                input_type_8 = []
                _input_type_8 = data
                for input_type_8_item_data in _input_type_8:
                    input_type_8_item = BaseGalileoStepInputType8Item.from_dict(input_type_8_item_data)

                    input_type_8.append(input_type_8_item)

                return input_type_8
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    "BaseGalileoStepInputType3",
                    "Document",
                    "Message",
                    list["BaseGalileoStepInputType7Item"],
                    list["BaseGalileoStepInputType8Item"],
                    list["Document"],
                    list["Message"],
                    list[str],
                    str,
                ],
                data,
            )

        input_ = _parse_input_(d.pop("input"))

        created_at_ns = d.pop("created_at_ns", UNSET)

        duration_ns = d.pop("duration_ns", UNSET)

        def _parse_ground_truth(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        ground_truth = _parse_ground_truth(d.pop("ground_truth", UNSET))

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, BaseGalileoStepMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = BaseGalileoStepMetadata.from_dict(_metadata)

        def _parse_metrics(data: object) -> Union[None, Unset, list["StepMetric"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                metrics_type_0 = []
                _metrics_type_0 = data
                for metrics_type_0_item_data in _metrics_type_0:
                    metrics_type_0_item = StepMetric.from_dict(metrics_type_0_item_data)

                    metrics_type_0.append(metrics_type_0_item)

                return metrics_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["StepMetric"]], data)

        metrics = _parse_metrics(d.pop("metrics", UNSET))

        name = d.pop("name", UNSET)

        def _parse_output(
            data: object,
        ) -> Union[
            "BaseGalileoStepOutputType3",
            "Document",
            "Message",
            Unset,
            list["BaseGalileoStepOutputType7Item"],
            list["BaseGalileoStepOutputType8Item"],
            list["Document"],
            list["Message"],
            list[str],
            str,
        ]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                output_type_1 = Document.from_dict(data)

                return output_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                output_type_2 = Message.from_dict(data)

                return output_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                output_type_3 = BaseGalileoStepOutputType3.from_dict(data)

                return output_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                output_type_4 = cast(list[str], data)

                return output_type_4
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                output_type_5 = []
                _output_type_5 = data
                for output_type_5_item_data in _output_type_5:
                    output_type_5_item = Document.from_dict(output_type_5_item_data)

                    output_type_5.append(output_type_5_item)

                return output_type_5
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                output_type_6 = []
                _output_type_6 = data
                for output_type_6_item_data in _output_type_6:
                    output_type_6_item = Message.from_dict(output_type_6_item_data)

                    output_type_6.append(output_type_6_item)

                return output_type_6
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                output_type_7 = []
                _output_type_7 = data
                for output_type_7_item_data in _output_type_7:
                    output_type_7_item = BaseGalileoStepOutputType7Item.from_dict(output_type_7_item_data)

                    output_type_7.append(output_type_7_item)

                return output_type_7
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, list):
                    raise TypeError()
                output_type_8 = []
                _output_type_8 = data
                for output_type_8_item_data in _output_type_8:
                    output_type_8_item = BaseGalileoStepOutputType8Item.from_dict(output_type_8_item_data)

                    output_type_8.append(output_type_8_item)

                return output_type_8
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    "BaseGalileoStepOutputType3",
                    "Document",
                    "Message",
                    Unset,
                    list["BaseGalileoStepOutputType7Item"],
                    list["BaseGalileoStepOutputType8Item"],
                    list["Document"],
                    list["Message"],
                    list[str],
                    str,
                ],
                data,
            )

        output = _parse_output(d.pop("output", UNSET))

        def _parse_root_workflow_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        root_workflow_id = _parse_root_workflow_id(d.pop("root_workflow_id", UNSET))

        def _parse_status_code(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        status_code = _parse_status_code(d.pop("status_code", UNSET))

        def _parse_step_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        step_id = _parse_step_id(d.pop("step_id", UNSET))

        def _parse_steps(data: object) -> Union[None, Unset, list["BaseGalileoStep"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                steps_type_0 = []
                _steps_type_0 = data
                for steps_type_0_item_data in _steps_type_0:
                    steps_type_0_item = BaseGalileoStep.from_dict(steps_type_0_item_data)

                    steps_type_0.append(steps_type_0_item)

                return steps_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["BaseGalileoStep"]], data)

        steps = _parse_steps(d.pop("steps", UNSET))

        type_ = d.pop("type", UNSET)

        def _parse_workflow_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        workflow_id = _parse_workflow_id(d.pop("workflow_id", UNSET))

        base_galileo_step = cls(
            input_=input_,
            created_at_ns=created_at_ns,
            duration_ns=duration_ns,
            ground_truth=ground_truth,
            metadata=metadata,
            metrics=metrics,
            name=name,
            output=output,
            root_workflow_id=root_workflow_id,
            status_code=status_code,
            step_id=step_id,
            steps=steps,
            type_=type_,
            workflow_id=workflow_id,
        )

        base_galileo_step.additional_properties = d
        return base_galileo_step

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="TopKToken")


@_attrs_define
class TopKToken:
    """Representation of a token and its probability for Segment Top k logprob tokens.

    Attributes:
        token: The text of the token
        prob: The probability of the token

        Attributes:
            prob (float):
            token (str):
    """

    prob: float
    token: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        prob = self.prob

        token = self.token

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"prob": prob, "token": token})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        prob = d.pop("prob")

        token = d.pop("token")

        top_k_token = cls(prob=prob, token=token)

        top_k_token.additional_properties = d
        return top_k_token

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.label_co_occurences import LabelCoOccurences


T = TypeVar("T", bound="MultiLabelCoOccurrence")


@_attrs_define
class MultiLabelCoOccurrence:
    """Label co-occurrence across tasks.

    Attributes:
        co_occurrences (list['LabelCoOccurences']):
        num_samples (int):
        percent_samples (float):
    """

    co_occurrences: list["LabelCoOccurences"]
    num_samples: int
    percent_samples: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        co_occurrences = []
        for co_occurrences_item_data in self.co_occurrences:
            co_occurrences_item = co_occurrences_item_data.to_dict()
            co_occurrences.append(co_occurrences_item)

        num_samples = self.num_samples

        percent_samples = self.percent_samples

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {"co_occurrences": co_occurrences, "num_samples": num_samples, "percent_samples": percent_samples}
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.label_co_occurences import LabelCoOccurences

        d = src_dict.copy()
        co_occurrences = []
        _co_occurrences = d.pop("co_occurrences")
        for co_occurrences_item_data in _co_occurrences:
            co_occurrences_item = LabelCoOccurences.from_dict(co_occurrences_item_data)

            co_occurrences.append(co_occurrences_item)

        num_samples = d.pop("num_samples")

        percent_samples = d.pop("percent_samples")

        multi_label_co_occurrence = cls(
            co_occurrences=co_occurrences, num_samples=num_samples, percent_samples=percent_samples
        )

        multi_label_co_occurrence.additional_properties = d
        return multi_label_co_occurrence

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.alert_monitor_type import AlertMonitorType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.alert_condition import AlertCondition


T = TypeVar("T", bound="CreateAlertConfigurationRequest")


@_attrs_define
class CreateAlertConfigurationRequest:
    """
    Attributes:
        conditions (list['AlertCondition']):
        interval (int):
        created_by (Union[None, Unset, str]):
        project_id (Union[None, Unset, str]):
        schema_version (Union[Unset, AlertMonitorType]):
    """

    conditions: list["AlertCondition"]
    interval: int
    created_by: Union[None, Unset, str] = UNSET
    project_id: Union[None, Unset, str] = UNSET
    schema_version: Union[Unset, AlertMonitorType] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        conditions = []
        for conditions_item_data in self.conditions:
            conditions_item = conditions_item_data.to_dict()
            conditions.append(conditions_item)

        interval = self.interval

        created_by: Union[None, Unset, str]
        if isinstance(self.created_by, Unset):
            created_by = UNSET
        else:
            created_by = self.created_by

        project_id: Union[None, Unset, str]
        if isinstance(self.project_id, Unset):
            project_id = UNSET
        else:
            project_id = self.project_id

        schema_version: Union[Unset, str] = UNSET
        if not isinstance(self.schema_version, Unset):
            schema_version = self.schema_version.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"conditions": conditions, "interval": interval})
        if created_by is not UNSET:
            field_dict["created_by"] = created_by
        if project_id is not UNSET:
            field_dict["project_id"] = project_id
        if schema_version is not UNSET:
            field_dict["schema_version"] = schema_version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.alert_condition import AlertCondition

        d = src_dict.copy()
        conditions = []
        _conditions = d.pop("conditions")
        for conditions_item_data in _conditions:
            conditions_item = AlertCondition.from_dict(conditions_item_data)

            conditions.append(conditions_item)

        interval = d.pop("interval")

        def _parse_created_by(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        created_by = _parse_created_by(d.pop("created_by", UNSET))

        def _parse_project_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        project_id = _parse_project_id(d.pop("project_id", UNSET))

        _schema_version = d.pop("schema_version", UNSET)
        schema_version: Union[Unset, AlertMonitorType]
        if isinstance(_schema_version, Unset):
            schema_version = UNSET
        else:
            schema_version = AlertMonitorType(_schema_version)

        create_alert_configuration_request = cls(
            conditions=conditions,
            interval=interval,
            created_by=created_by,
            project_id=project_id,
            schema_version=schema_version,
        )

        create_alert_configuration_request.additional_properties = d
        return create_alert_configuration_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class JobStatus(str, Enum):
    COMPLETED = "completed"
    ERROR = "error"
    FAILED = "failed"
    IN_PROGRESS = "in_progress"
    UNSTARTED = "unstarted"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Literal, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="DatasetAddColumn")


@_attrs_define
class DatasetAddColumn:
    """
    Attributes:
        column_values (list[Union[None, float, int, str]]):
        new_column_name (str):
        edit_type (Union[Literal['add_column'], Unset]):  Default: 'add_column'.
    """

    column_values: list[Union[None, float, int, str]]
    new_column_name: str
    edit_type: Union[Literal["add_column"], Unset] = "add_column"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        column_values = []
        for column_values_item_data in self.column_values:
            column_values_item: Union[None, float, int, str]
            column_values_item = column_values_item_data
            column_values.append(column_values_item)

        new_column_name = self.new_column_name

        edit_type = self.edit_type

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"column_values": column_values, "new_column_name": new_column_name})
        if edit_type is not UNSET:
            field_dict["edit_type"] = edit_type

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        column_values = []
        _column_values = d.pop("column_values")
        for column_values_item_data in _column_values:

            def _parse_column_values_item(data: object) -> Union[None, float, int, str]:
                if data is None:
                    return data
                return cast(Union[None, float, int, str], data)

            column_values_item = _parse_column_values_item(column_values_item_data)

            column_values.append(column_values_item)

        new_column_name = d.pop("new_column_name")

        edit_type = cast(Union[Literal["add_column"], Unset], d.pop("edit_type", UNSET))
        if edit_type != "add_column" and not isinstance(edit_type, Unset):
            raise ValueError(f"edit_type must match const 'add_column', got '{edit_type}'")

        dataset_add_column = cls(column_values=column_values, new_column_name=new_column_name, edit_type=edit_type)

        dataset_add_column.additional_properties = d
        return dataset_add_column

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="EvaluateRunResultsRequest")


@_attrs_define
class EvaluateRunResultsRequest:
    """
    Attributes:
        limit (Union[Unset, int]):  Default: 100.
        project_id (Union[None, Unset, str]):
        project_name (Union[None, Unset, str]):
        run_id (Union[None, Unset, str]):
        run_name (Union[None, Unset, str]):
        starting_token (Union[Unset, int]):  Default: 0.
    """

    limit: Union[Unset, int] = 100
    project_id: Union[None, Unset, str] = UNSET
    project_name: Union[None, Unset, str] = UNSET
    run_id: Union[None, Unset, str] = UNSET
    run_name: Union[None, Unset, str] = UNSET
    starting_token: Union[Unset, int] = 0
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        limit = self.limit

        project_id: Union[None, Unset, str]
        if isinstance(self.project_id, Unset):
            project_id = UNSET
        else:
            project_id = self.project_id

        project_name: Union[None, Unset, str]
        if isinstance(self.project_name, Unset):
            project_name = UNSET
        else:
            project_name = self.project_name

        run_id: Union[None, Unset, str]
        if isinstance(self.run_id, Unset):
            run_id = UNSET
        else:
            run_id = self.run_id

        run_name: Union[None, Unset, str]
        if isinstance(self.run_name, Unset):
            run_name = UNSET
        else:
            run_name = self.run_name

        starting_token = self.starting_token

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if limit is not UNSET:
            field_dict["limit"] = limit
        if project_id is not UNSET:
            field_dict["project_id"] = project_id
        if project_name is not UNSET:
            field_dict["project_name"] = project_name
        if run_id is not UNSET:
            field_dict["run_id"] = run_id
        if run_name is not UNSET:
            field_dict["run_name"] = run_name
        if starting_token is not UNSET:
            field_dict["starting_token"] = starting_token

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        limit = d.pop("limit", UNSET)

        def _parse_project_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        project_id = _parse_project_id(d.pop("project_id", UNSET))

        def _parse_project_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        project_name = _parse_project_name(d.pop("project_name", UNSET))

        def _parse_run_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        run_id = _parse_run_id(d.pop("run_id", UNSET))

        def _parse_run_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        run_name = _parse_run_name(d.pop("run_name", UNSET))

        starting_token = d.pop("starting_token", UNSET)

        evaluate_run_results_request = cls(
            limit=limit,
            project_id=project_id,
            project_name=project_name,
            run_id=run_id,
            run_name=run_name,
            starting_token=starting_token,
        )

        evaluate_run_results_request.additional_properties = d
        return evaluate_run_results_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.distribution import Distribution
    from ..models.multi_label_task_metrics import MultiLabelTaskMetrics


T = TypeVar("T", bound="ModelMetrics")


@_attrs_define
class ModelMetrics:
    """
    Attributes:
        accuracy (float):
        f1 (float):
        precision (float):
        recall (float):
        confidence (Union[None, Unset, float]):
        dep_distribution (Union['Distribution', None, Unset]):
        multi_label_task_metrics (Union[Unset, MultiLabelTaskMetrics]): Metrics per task for multi-label models.
    """

    accuracy: float
    f1: float
    precision: float
    recall: float
    confidence: Union[None, Unset, float] = UNSET
    dep_distribution: Union["Distribution", None, Unset] = UNSET
    multi_label_task_metrics: Union[Unset, "MultiLabelTaskMetrics"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.distribution import Distribution

        accuracy = self.accuracy

        f1 = self.f1

        precision = self.precision

        recall = self.recall

        confidence: Union[None, Unset, float]
        if isinstance(self.confidence, Unset):
            confidence = UNSET
        else:
            confidence = self.confidence

        dep_distribution: Union[None, Unset, dict[str, Any]]
        if isinstance(self.dep_distribution, Unset):
            dep_distribution = UNSET
        elif isinstance(self.dep_distribution, Distribution):
            dep_distribution = self.dep_distribution.to_dict()
        else:
            dep_distribution = self.dep_distribution

        multi_label_task_metrics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.multi_label_task_metrics, Unset):
            multi_label_task_metrics = self.multi_label_task_metrics.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"accuracy": accuracy, "f1": f1, "precision": precision, "recall": recall})
        if confidence is not UNSET:
            field_dict["confidence"] = confidence
        if dep_distribution is not UNSET:
            field_dict["dep_distribution"] = dep_distribution
        if multi_label_task_metrics is not UNSET:
            field_dict["multi_label_task_metrics"] = multi_label_task_metrics

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.distribution import Distribution
        from ..models.multi_label_task_metrics import MultiLabelTaskMetrics

        d = src_dict.copy()
        accuracy = d.pop("accuracy")

        f1 = d.pop("f1")

        precision = d.pop("precision")

        recall = d.pop("recall")

        def _parse_confidence(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        confidence = _parse_confidence(d.pop("confidence", UNSET))

        def _parse_dep_distribution(data: object) -> Union["Distribution", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                dep_distribution_type_0 = Distribution.from_dict(data)

                return dep_distribution_type_0
            except:  # noqa: E722
                pass
            return cast(Union["Distribution", None, Unset], data)

        dep_distribution = _parse_dep_distribution(d.pop("dep_distribution", UNSET))

        _multi_label_task_metrics = d.pop("multi_label_task_metrics", UNSET)
        multi_label_task_metrics: Union[Unset, MultiLabelTaskMetrics]
        if isinstance(_multi_label_task_metrics, Unset):
            multi_label_task_metrics = UNSET
        else:
            multi_label_task_metrics = MultiLabelTaskMetrics.from_dict(_multi_label_task_metrics)

        model_metrics = cls(
            accuracy=accuracy,
            f1=f1,
            precision=precision,
            recall=recall,
            confidence=confidence,
            dep_distribution=dep_distribution,
            multi_label_task_metrics=multi_label_task_metrics,
        )

        model_metrics.additional_properties = d
        return model_metrics

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class PolygonSize(str, Enum):
    EXTRA_LARGE = "extra_large"
    EXTRA_SMALL = "extra_small"
    LARGE = "large"
    MEDIUM = "medium"
    SMALL = "small"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.weekly_changelog_changes import WeeklyChangelogChanges


T = TypeVar("T", bound="WeeklyChangelog")


@_attrs_define
class WeeklyChangelog:
    """
    Attributes:
        week_of (datetime.date):
        changes (Union[Unset, WeeklyChangelogChanges]):
    """

    week_of: datetime.date
    changes: Union[Unset, "WeeklyChangelogChanges"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        week_of = self.week_of.isoformat()

        changes: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.changes, Unset):
            changes = self.changes.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"week_of": week_of})
        if changes is not UNSET:
            field_dict["changes"] = changes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.weekly_changelog_changes import WeeklyChangelogChanges

        d = src_dict.copy()
        week_of = isoparse(d.pop("week_of")).date()

        _changes = d.pop("changes", UNSET)
        changes: Union[Unset, WeeklyChangelogChanges]
        if isinstance(_changes, Unset):
            changes = UNSET
        else:
            changes = WeeklyChangelogChanges.from_dict(_changes)

        weekly_changelog = cls(week_of=week_of, changes=changes)

        weekly_changelog.additional_properties = d
        return weekly_changelog

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.llm_integration import LLMIntegration
from ..types import UNSET, Unset

T = TypeVar("T", bound="ModelInfo")


@_attrs_define
class ModelInfo:
    """Model information that is useful to surface to the UI and in other contexts.

    This is a subset of all of the information we store about the model. We need a lot more
    information to actually execute requests against the model, but that is not necessary
    to surface to the user.

        Attributes:
            alias (str):
            name (str):
            assistant_role (Union[None, Unset, str]):
            integration (Union[Unset, LLMIntegration]):
            system_supported (Union[Unset, bool]):  Default: False.
            user_role (Union[None, Unset, str]):
    """

    alias: str
    name: str
    assistant_role: Union[None, Unset, str] = UNSET
    integration: Union[Unset, LLMIntegration] = UNSET
    system_supported: Union[Unset, bool] = False
    user_role: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        alias = self.alias

        name = self.name

        assistant_role: Union[None, Unset, str]
        if isinstance(self.assistant_role, Unset):
            assistant_role = UNSET
        else:
            assistant_role = self.assistant_role

        integration: Union[Unset, str] = UNSET
        if not isinstance(self.integration, Unset):
            integration = self.integration.value

        system_supported = self.system_supported

        user_role: Union[None, Unset, str]
        if isinstance(self.user_role, Unset):
            user_role = UNSET
        else:
            user_role = self.user_role

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"alias": alias, "name": name})
        if assistant_role is not UNSET:
            field_dict["assistant_role"] = assistant_role
        if integration is not UNSET:
            field_dict["integration"] = integration
        if system_supported is not UNSET:
            field_dict["system_supported"] = system_supported
        if user_role is not UNSET:
            field_dict["user_role"] = user_role

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        alias = d.pop("alias")

        name = d.pop("name")

        def _parse_assistant_role(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        assistant_role = _parse_assistant_role(d.pop("assistant_role", UNSET))

        _integration = d.pop("integration", UNSET)
        integration: Union[Unset, LLMIntegration]
        if isinstance(_integration, Unset):
            integration = UNSET
        else:
            integration = LLMIntegration(_integration)

        system_supported = d.pop("system_supported", UNSET)

        def _parse_user_role(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        user_role = _parse_user_role(d.pop("user_role", UNSET))

        model_info = cls(
            alias=alias,
            name=name,
            assistant_role=assistant_role,
            integration=integration,
            system_supported=system_supported,
            user_role=user_role,
        )

        model_info.additional_properties = d
        return model_info

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="Changes")


@_attrs_define
class Changes:
    """
    Attributes:
        breaking (Union[Unset, list[str]]):
        features (Union[Unset, list[str]]):
        fixes (Union[Unset, list[str]]):
        miscellaneous (Union[Unset, list[str]]):
    """

    breaking: Union[Unset, list[str]] = UNSET
    features: Union[Unset, list[str]] = UNSET
    fixes: Union[Unset, list[str]] = UNSET
    miscellaneous: Union[Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        breaking: Union[Unset, list[str]] = UNSET
        if not isinstance(self.breaking, Unset):
            breaking = self.breaking

        features: Union[Unset, list[str]] = UNSET
        if not isinstance(self.features, Unset):
            features = self.features

        fixes: Union[Unset, list[str]] = UNSET
        if not isinstance(self.fixes, Unset):
            fixes = self.fixes

        miscellaneous: Union[Unset, list[str]] = UNSET
        if not isinstance(self.miscellaneous, Unset):
            miscellaneous = self.miscellaneous

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if breaking is not UNSET:
            field_dict["breaking"] = breaking
        if features is not UNSET:
            field_dict["features"] = features
        if fixes is not UNSET:
            field_dict["fixes"] = fixes
        if miscellaneous is not UNSET:
            field_dict["miscellaneous"] = miscellaneous

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        breaking = cast(list[str], d.pop("breaking", UNSET))

        features = cast(list[str], d.pop("features", UNSET))

        fixes = cast(list[str], d.pop("fixes", UNSET))

        miscellaneous = cast(list[str], d.pop("miscellaneous", UNSET))

        changes = cls(breaking=breaking, features=features, fixes=fixes, miscellaneous=miscellaneous)

        changes.additional_properties = d
        return changes

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CollaboratorRole(str, Enum):
    ANNOTATOR = "annotator"
    EDITOR = "editor"
    OWNER = "owner"
    VIEWER = "viewer"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.query_filter_v1 import QueryFilterV1
    from ..models.sort_clause import SortClause


T = TypeVar("T", bound="TransactionRowsRequestBody")


@_attrs_define
class TransactionRowsRequestBody:
    """
    Attributes:
        columns (Union[None, Unset, list[str]]):
        filters (Union[Unset, list['QueryFilterV1']]):
        sort_spec (Union[Unset, list['SortClause']]):
    """

    columns: Union[None, Unset, list[str]] = UNSET
    filters: Union[Unset, list["QueryFilterV1"]] = UNSET
    sort_spec: Union[Unset, list["SortClause"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        columns: Union[None, Unset, list[str]]
        if isinstance(self.columns, Unset):
            columns = UNSET
        elif isinstance(self.columns, list):
            columns = self.columns

        else:
            columns = self.columns

        filters: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.filters, Unset):
            filters = []
            for filters_item_data in self.filters:
                filters_item = filters_item_data.to_dict()
                filters.append(filters_item)

        sort_spec: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.sort_spec, Unset):
            sort_spec = []
            for sort_spec_item_data in self.sort_spec:
                sort_spec_item = sort_spec_item_data.to_dict()
                sort_spec.append(sort_spec_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if columns is not UNSET:
            field_dict["columns"] = columns
        if filters is not UNSET:
            field_dict["filters"] = filters
        if sort_spec is not UNSET:
            field_dict["sort_spec"] = sort_spec

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.query_filter_v1 import QueryFilterV1
        from ..models.sort_clause import SortClause

        d = src_dict.copy()

        def _parse_columns(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                columns_type_0 = cast(list[str], data)

                return columns_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        columns = _parse_columns(d.pop("columns", UNSET))

        filters = []
        _filters = d.pop("filters", UNSET)
        for filters_item_data in _filters or []:
            filters_item = QueryFilterV1.from_dict(filters_item_data)

            filters.append(filters_item)

        sort_spec = []
        _sort_spec = d.pop("sort_spec", UNSET)
        for sort_spec_item_data in _sort_spec or []:
            sort_spec_item = SortClause.from_dict(sort_spec_item_data)

            sort_spec.append(sort_spec_item)

        transaction_rows_request_body = cls(columns=columns, filters=filters, sort_spec=sort_spec)

        transaction_rows_request_body.additional_properties = d
        return transaction_rows_request_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
